import React from 'react'
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import dynamic from 'next/dynamic';
import i18n from '../../i18n';

const FontIcon = dynamic(() => import('./FontIcon'), { ssr: false })


function AdminUsersList({ tableHeader, Details, handleModal, parkingLots }) {
    return (
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: '75vh',
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                borderCollapse: 'collapse',
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300,
                    width: '120px',
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif'

                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: i18n.language == 'en' ? 700 : 500,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif'
                },
            }}
                aria-label="simple table">
                <TableHead >
                    <TableRow>
                        {
                            tableHeader.map((head, index) => {
                                return (
                                    <TableCell className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}`} key={index} align='center'>{head?.title}</TableCell>
                                )
                            })
                        }
                    </TableRow>
                </TableHead>
                <TableBody>
                    {Details.map((user, index) => (
                        <TableRow
                            key={index}
                            sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                        >
                            <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.firstName + ' ' + user?.middleName + ' ' + user?.lastName}</TableCell>
                            <TableCell style={{ verticalAlign: 'top' }} align="center">{parkingLots?.filter(obj => user?.parkingLots?.includes(obj?._id)).length > 0 ? parkingLots?.filter(obj => user?.parkingLots?.includes(obj?._id))?.map(obj => obj?.name).join(' - ') : '-'}</TableCell>
                            <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.phoneNumber?.number}</TableCell>
                            <TableCell style={{ verticalAlign: 'top' }} align="center">{user?.email}</TableCell>
                            <TableCell style={{ verticalAlign: 'top' }} align="center">{<FontIcon handleClick={() => handleModal(user?._id)} iconname="fa-solid fa-trash-can" size="lg" className='text-appLightGrey  hover:text-appSeaGreen hover:cursor-pointer' />}   </TableCell>
                        </TableRow>
                    ))}
                </TableBody>
            </Table>
        </TableContainer>
    )
}

export default AdminUsersList