import Loader from '@/pages/Loader'
import dynamic from 'next/dynamic'
import React, { useState } from 'react'
import { useTranslation } from 'react-i18next'
import { useDispatch, useSelector } from 'react-redux'
import i18n from '../../i18n'
import InputField from './InputField'
import { InputLabel } from '@mui/material'
import moment from 'moment'
import { createHoliday } from '@/store/userReducer'

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


const CreateHoliday = ({ setCreateHoliday }) => {
    const { t } = useTranslation()
    const { loader } = useSelector(state => state.user)
    const dispatch = useDispatch()

    const [holidayDetails, setHolidayDetails] = useState({
        name: "",
        sDate: "",
        eDate: "",
        startTime: "",
        endTime: "",
        startDate: '',
        endDate: ''

    })

    const formConfig = [
        { key: 'holidayName', name: 'name', type: 'text' },
        { key: 'starttime', name: 'startTime', type: 'time' },
        { key: 'startdate', name: 'sDate', type: 'date' },
        { key: 'endtime', name: 'endTime', type: 'time' },
        { key: 'enddate', name: 'eDate', type: 'date' },
    ]

    const handleChange = (value, name) => {
        const updateHolidayDetails = { ...holidayDetails }
        if (name === 'startTime') {
            updateHolidayDetails[name] = value;
            const currentDate = holidayDetails['sDate'] ? moment.utc(holidayDetails['sDate']).format('YYYY-MM-DD') : moment(new Date()).format();
            updateHolidayDetails['startDate'] = moment(`${currentDate} ${value}`, 'YYYY-MM-DD HH:mm').format('YYYY-MM-DDTHH:mm:ss.SSS[Z]');
        } else if (name == 'sDate') {
            updateHolidayDetails[name] = value
            updateHolidayDetails['startDate'] = moment(`${value} ${holidayDetails['startTime'] ? holidayDetails['startTime'] : '00:00'}`, 'YYYY-MM-DDTHH:mm').format('YYYY-MM-DDTHH:mm:ss.SSS[Z]')
        } else if (name == 'endTime') {
            updateHolidayDetails[name] = value;
            const currentDate = holidayDetails['eDate'] ? moment.utc(holidayDetails['eDate']).format('YYYY-MM-DD') : moment(new Date()).format();
            updateHolidayDetails['endDate'] = moment(`${currentDate} ${value}`, 'YYYY-MM-DDTHH:mm').format('YYYY-MM-DDTHH:mm:ss.SSS[Z]');
        } else if (name == 'eDate') {
            updateHolidayDetails[name] = value
            updateHolidayDetails['endDate'] = moment(`${value} ${holidayDetails['endTime'] ? holidayDetails['endTime'] : '00:00'}`, 'YYYY-MM-DDTHH:mm').format('YYYY-MM-DDTHH:mm:ss.SSS[Z]')
        } else {
            updateHolidayDetails[name] = value
        }
        setHolidayDetails(updateHolidayDetails)
    }

    const isFieldCheck = () => {
        const { name, sDate, eDate, startTime, endTime, startDate, endDate } = holidayDetails
        if (!sDate || !eDate || !startTime || !endTime || !startDate || !endDate) {
            alert('Please fill in all fields.');
            return false;
        }

        const startDateTime = moment(`${startDate}`, 'YYYY-MM-DD HH:mm');
        const endDateTime = moment(`${endDate}`, 'YYYY-MM-DD HH:mm');

        if (!startDateTime.isBefore(endDateTime)) {
            alert('Please check, Start time or date must be before End time or date.');
            return false;
        }
        return true
    }

    const handleSubmit = (e) => {
        e.preventDefault()
        if (isFieldCheck()) {
            dispatch(createHoliday({ data: holidayDetails, setCreateHoliday: () => setCreateHoliday() }))
        }
    }

    return (
        <>
            {loader && <Loader />}
            <div className='flex flex-row items-center justify-between mt-8 mx-12'>
                <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[30px]`}>{t('createholiday')}</h1>
                <FontIcon handleClick={() => { setCreateHoliday() }} size='xl' iconname="fa-solid fa-xmark" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen ' />
            </div>
            <form onSubmit={handleSubmit} className='mt-12'>
                <div className='flex flex-wrap mx-20 gap-5'>
                    {formConfig?.map((config, index) => {
                        return (
                            <div key={index} className='w-[30%]'>
                                <InputLabel htmlFor={config.key}><p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} text-appBlack`}> {t(config.key)}</p> </InputLabel>
                                <InputField
                                    required={false}
                                    type={config.type}
                                    id={config.key}
                                    name={config.key}
                                    value={holidayDetails[config.name]}
                                    onChange={(e) => handleChange(e.target.value, config.name)}
                                />
                            </div>
                        )
                    })
                    }
                </div>
                <div className='flex  mb-10  mt-16 items-center justify-center'>
                    <button
                        type='submit'
                        className={`bg-transparent transition-all delay-100 hover:bg-appSeaGreen hover:text-appWhite w-[204px] h-[59px] text-appSeaGreen border-2 border-appSeaGreen  rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-bold font-spartan' : 'font-rubik font-medium'} cursor-pointer `}
                    >
                        {t('createholiday')}
                    </button>
                </div>
            </form>
        </>
    )
}

export default CreateHoliday