import { InputLabel, MenuItem, Select } from '@mui/material';
import Autocomplete from '@mui/joy/Autocomplete';
import dynamic from 'next/dynamic'
import React, { useEffect, useState } from 'react'
import InputField from './InputField';
import { useSelector, useDispatch } from 'react-redux';
import { createGuestUser, createUser, getParkingLotLevels, getParkingLots, getParkingSpots } from '@/store/userReducer';
import Loader from '@/pages/Loader';
import { useTranslation } from 'react-i18next';
import i18n from '../../i18n';
import { svgImages } from '@/utilities/utils';
import Image from 'next/image';
import { Calendar } from "@nextui-org/calendar";
import { now } from "@internationalized/date";
import moment from 'moment';

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


function CreateUser({ setCreateUser, guestUser = false, selectedParkingLot }) {
    const { t } = useTranslation()
    const { loader, login, allUsers, parkingSpots, parkingLevels, parkingLots, adminData } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const [selectedDate, setSelectedDate] = useState(now())
    const [showCalender, setShowCalender] = useState(false)
    const [formatedDate, setFormatedDate] = useState()
    const [inputErr, setInputErr] = useState(false)
    const [adminDetail, setAdminDetail] = useState({
        firstName: '',
        // registration: '',
        accessibleParkingSpot: guestUser ? false : '',
        phoneNumber: {
            countryCode: "+972",
            number: ""
        },
        electricCharging: guestUser ? false : '',
        email: ''
    });

    const allowedlot = {
        parkinglot: '',
        designatedParkingSpot: '',
        designatedParkingSpotOptions: []
    }
    const [allowedLots, setAllowedLots] = useState([allowedlot])
    const [mainParkingLot, setMainParkingLot] = useState('')

    const vehicle = {
        make: "",
        model: "",
        registration: ""
    }
    const [vehicles, setVehicles] = useState([vehicle])

    let mainParkingLotconfig = {
        key: 'mainparkinglot', type: 'select', options: parkingLots?.parkingLots?.filter(obj => allowedLots?.some(item => item.parkinglot === obj._id)) || []
    }

    const allowedlotsconfig = [
        { key: 'parkinglot', type: 'select', options: parkingLots?.parkingLots || [] },
        { key: 'designatedParkingSpot', type: 'select', options: [] },
    ]

    const formConfig = [
        { key: 'firstName', label: 'Name', type: 'text' },
        { key: 'phoneNumber', label: 'Phone Number', type: 'text' },
        { key: 'email', label: 'Email', type: 'email' },
        // { key: 'registration', label: 'Vehicle Number', type: 'text' },
        { key: 'electricCharging', label: 'Electric Charging', type: guestUser ? 'checkbox' : 'select', options: ['Yes', 'No'] },
        { key: 'accessibleParkingSpot', label: 'Accessible Parking Spot', type: guestUser ? 'checkbox' : 'select', options: ['Yes', 'No'] },
    ];

    const handleChangeAllowedLot = async (value, index, key) => {
        const updatedLots = [...allowedLots];
        updatedLots[index][key] = value;
        setAllowedLots(updatedLots);
        if (key == 'parkinglot') {
            dispatch(getParkingSpots({
                token: adminData?.token, parkingLotId: value, fromCreate_UpdateUser: true,
                setAllowedLots, allowedLots, index, isAvailable: true, type: 'designated',
            }))
        }
    };

    const handleChange = (e, key) => {
        setAdminDetail({
            ...adminDetail,
            [key]: key == 'phoneNumber' ? { ...adminDetail?.phoneNumber, number: e.target.value } : e.target.value,
        });
    };

    const handleVehicleChange = (e, index) => {
        const updatedVehicles = [...vehicles]
        updatedVehicles[index]['registration'] = e.target.value
        setVehicles(updatedVehicles)
    }

    const isFormValid = () => {
        const {
            firstName,
            // registration,
            phoneNumber,
            electricCharging,
            // email,
            accessibleParkingSpot
        } = adminDetail;

        const isAllAllowedLotsFilled = allowedLots.every(row =>
            Object.values(row).every(value => value !== '')
        );
        const isAllVehiclesFilled = vehicles.every(row =>
            row.registration.trim() !== ''
        );

        const requiredFieldsFilled =
            firstName !== '' &&
            // registration !== '' &&
            phoneNumber.countryCode !== '' &&
            phoneNumber.number !== '' &&
            electricCharging !== '' &&
            // email !== '' &&
            accessibleParkingSpot !== '' &&
            mainParkingLot !== '';


        if (requiredFieldsFilled && isAllAllowedLotsFilled && isAllVehiclesFilled) {
            return true;
        } else {
            console.log('Please fill in all required fields.');
            return false;
        }
    };

    const alertMsg = (msg) => {
        alert(msg)
    }

    const handleSubmit = (e) => {
        e.preventDefault();
        setInputErr(true)
        if (isFormValid()) {
            if (guestUser) {
                dispatch(createGuestUser({
                    data: adminDetail, vehicles: vehicles, mainParkingLot: mainParkingLot, allowedLots: allowedLots, setCreateUser: () => setCreateUser(), setUserDetail: () => {
                        setAdminDetail({
                            firstName: '',
                            registration: '',
                            phoneNumber: {
                                countryCode: "+972",
                                number: ""
                            },
                            electricCharging: false,
                            email: '',
                            accessibleParkingSpot: false
                        })
                    },
                    selectedParkingLot: selectedParkingLot,
                    reservationDate: new Date(moment(formatedDate).format()),
                    alert: alertMsg
                }))
            } else {
                dispatch(createUser({
                    token: adminData?.token, data: adminDetail, vehicles: vehicles, mainParkingLot: mainParkingLot, allowedLots: allowedLots, setCreateUser: () => setCreateUser(), setUserDetail: () => {
                        setAdminDetail({
                            firstName: '',
                            registration: '',
                            phoneNumber: {
                                countryCode: "+972",
                                number: ""
                            },
                            electricCharging: '',
                            email: '',
                            accessibleParkingSpot: ''
                        })
                    },
                    alert: alertMsg
                }))
            }
            // console.log('new user =====', adminDetail, allowedLots, mainParkingLot)
        }
    };

    const handleDeleteLot = (id) => {
        const lots = allowedLots.filter((item, index) => index != id)
        setAllowedLots(lots)
    }

    const handleDeleteVehicle = (id) => {
        const updatedVehicles = vehicles.filter((item, index) => index != id)
        setVehicles(updatedVehicles)
    }

    useEffect(() => {
        if (!allowedLots.some(obj => obj?.parkinglot == mainParkingLot)) {
            setMainParkingLot('')
        }
    }, [allowedLots])

    // useEffect(() => {
    //     if (guestUser) {
    //         setShowCalender(true)
    //     }
    // }, [guestUser])

    useEffect(() => {
        setFormatedDate({
            ...selectedDate,
            month: selectedDate?.month - 1
        })
    }, [selectedDate])



    return (
        <>
            {loader && <Loader />}
            <div className='flex flex-row items-center justify-between mt-8 mx-12'>
                <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[30px]`}>{guestUser ? t('createGuestUserhead') : t('createUserhead')}</h1>
                <FontIcon handleClick={() => { setCreateUser() }} size='xl' iconname="fa-solid fa-xmark" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen ' />
            </div>

            <form onSubmit={handleSubmit} className='flex flex-col gap-0 justify-center mx-12 mt-[30px] '>
                <div className='flex w-[70%] items-center  gap-10 flex-wrap'>
                    {formConfig.map((config, index) => (
                        <div className='flex flex-col w-[25%] self-start' key={index}>
                            <InputLabel htmlFor={config.key}><p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} text-appBlack`}> {config.type != 'checkbox' && t(config.key)}</p> </InputLabel>
                            {config.type === 'select' ? (
                                <Select
                                    required={false}
                                    id={config.key}
                                    disabled={(config.key == 'designatedParkingSpot' && (adminDetail.designatedParkingSpotSet == 'No' || adminDetail?.designatedParkingSpotSet == '')) || (config.key == 'mainParkingLot' && adminDetail?.allowedParkingLots?.length == 0) || (config.key == 'designatedParkingSpotSet' && adminDetail?.mainParkingLot == '') ? true : false}
                                    name={config.key}
                                    value={adminDetail[config.key]}
                                    onChange={(e) => handleChange(e, config.key)}
                                    className="mt-1 w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                    displayEmpty
                                    multiple={config.key == 'allowedParkingLots'}
                                    sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}
                                >
                                    <MenuItem value='' disabled>
                                        {t('adminSelectoption')}
                                    </MenuItem>
                                    {config.options.map((option, index) => (
                                        <MenuItem sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }} key={index} value={config.key == 'allowedParkingLots' || config.key == 'mainParkingLot' || config.key == 'designatedParkingSpot' ? option._id : option}>
                                            {option?.parkingCode || option?.name || option?.level ? (option?.parkingCode || option?.name || option?.level) : option}
                                        </MenuItem>
                                    ))}
                                </Select>
                            ) : config.type === 'empty' ? null : config.type == 'checkbox' ? <div className='flex items-center gap-2'>
                                <Image onClick={() => handleChange({
                                    target: {
                                        value: !adminDetail[config.key]
                                    }
                                }, config.key)} alt='checkbox icon' className='w-6 h-6 cursor-pointer' src={adminDetail[config.key] ? svgImages.dropdowncheckbox : svgImages.dropdownuncheckedcheckbox} />
                                <p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} text-appBlack`}>{config.type == 'checkbox' && t(config.key)}</p>
                            </div> : (
                                <InputField
                                    required={false}
                                    disabled={config.key == 'designatedParkingSpot' && adminDetail?.designatedParkingSpotSet != 'Yes'}
                                    type={config.type}
                                    id={config.key}
                                    name={config.key}
                                    value={config.key == 'phoneNumber' ? adminDetail[config.key].number : adminDetail[config.key]}
                                    onChange={(e) => handleChange(e, config.key)}
                                />
                            )
                            }
                            {inputErr && <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${(adminDetail[config.key] == '' || adminDetail[config.key]?.number == '') ? 'visible' : 'invisible'}`}>{(config.type !== 'checkbox' && config.key !== 'email' && config.key != 'designatedParkingSpot') && t('fillalert')}</p>}
                            <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${(inputErr && config.key == 'designatedParkingSpot' && adminDetail?.designatedParkingSpot == '' && adminDetail.designatedParkingSpotSet == 'Yes') ? 'visible' : 'invisible'} `}>{t('fillalert')}</p>
                        </div>
                    ))}
                    
                </div>
                
                {
                    guestUser && (
                        <div onClick={()=>{setShowCalender(true) }} >
                        <div  className='flex flex-col gap-3 my-2 justify-start'>
                       <p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} mt-4  text-appBlack `}>{t('reservationDate')}</p>
                       <div className='w-[17%]'>
                           <InputField
                               required={false}
                               type={'text'}
                               value={moment(formatedDate)?.format('YYYY MMM DD')}
                           />
                       </div>

                   </div>
           </div>
                    )
                }
                   

                <div className='flex items-center justify-start gap-3'>
                    <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[22px] mt-5`}>{t('vehicles')} </h1>
                    <FontIcon handleClick={() => setVehicles([...vehicles, vehicle])} size='lg' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full mt-4 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md ' />
                </div>
                {
                    vehicles.map((vehicle, index) => {
                        return (
                            <div key={index} className='flex gap-3 my-2 justify-start'>
                                <p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} mt-4  text-appBlack `}>{t('registration')}</p>
                                <div className='w-[17%]'>
                                    <InputField
                                        required={false}
                                        type={'text'}
                                        value={vehicle.registration}
                                        onChange={(e) => handleVehicleChange(e, index)}
                                    />
                                    {inputErr && <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${vehicle.registration == '' ? 'visible' : 'invisible'}`}>{t('fillalert')}</p>}
                                </div>

                                <FontIcon handleClick={() => { handleDeleteVehicle(index) }} className={`${vehicles?.length > 1 ? 'visible' : 'invisible'} mt-4 text-appLightGrey  rounded-full hover:cursor-pointer hover:text-appSeaGreen `} iconname={'fa-solid fa-trash-can'} size={'sm'} />
                            </div>
                        )
                    })
                }


                <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[22px] mt-5`}>{t('allowedParkingLotsnew')}:</h1>

                <div className='w-[55%] '>
                    <div className='flex items-center justify-around py-3 border-b-[1px] border-appSeaGreen'>
                        <p className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[15px]`}>{t('parkingLot')}</p>
                        <p className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[15px]`}>{t('designatedparkingspotnew')}</p>
                    </div>

                    {allowedLots?.map((lot, index) => {
                        const parkingOptions = lot?.designatedParkingSpotOptions || [];
                        const optionsWithNo = [{ _id: '1', parkingCode: 'No' }, ...parkingOptions];
                        return (
                            <div key={index} className='flex gap-10 items-center mt-2 border-b-[1px] border-appSeaGreen pb-3'>
                                {allowedlotsconfig?.map((lotConfig, configIndex) => {
                                    return (
                                        <div key={configIndex} className='w-full'>
                                            {lotConfig?.key != 'designatedParkingSpot' ? <Select
                                                key={configIndex}
                                                required={false}
                                                value={allowedLots[index][lotConfig.key]}
                                                onChange={(e) => handleChangeAllowedLot(e.target.value, index, lotConfig.key)}
                                                className="mt-1 w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                                displayEmpty
                                                sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}
                                            >
                                                <MenuItem value='' disabled>
                                                    {t('adminSelectoption')}
                                                </MenuItem>
                                                {
                                                    // lotConfig?.key != 'designatedParkingSpot' ?
                                                    lotConfig?.options?.map((option, optionIndex) => (
                                                        <MenuItem key={optionIndex} sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }} value={option?._id ? option?._id : option}>
                                                            {option?._id ? option?.name : option}
                                                        </MenuItem>
                                                    ))
                                                    // : optionsWithNo?.map((spot, index) => (
                                                    //     <MenuItem key={index} value={spot?._id}>
                                                    //         {spot?.parkingCode}
                                                    //     </MenuItem>
                                                    // ))
                                                }
                                            </Select> : <Autocomplete
                                                key={configIndex}
                                                value={allowedLots[index][lotConfig.key]}
                                                onChange={(e, value) => handleChangeAllowedLot(value, index, lotConfig.key)}
                                                options={optionsWithNo}
                                                disabled = {allowedLots[index].parkinglot == ''}
                                                getOptionLabel={(option) => option?.parkingCode ? option?.parkingCode : ''}
                                                className='h-[43px] mt-1'
                                                placeholder={t('adminSelectoption')}
                                            />}
                                            <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${(inputErr && allowedLots[index][lotConfig.key] == '') ? 'visible' : 'hidden'}`} >{t('fillalert')}</p>
                                        </div>
                                    );
                                })}
                                <FontIcon handleClick={() => { handleDeleteLot(index) }} className={`${allowedLots?.length > 1 ? 'visible' : 'invisible'} text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen `} iconname={'fa-solid fa-trash-can'} size={'sm'} />
                            </div>
                        );
                    })}

                    <FontIcon handleClick={() => setAllowedLots([...allowedLots, allowedlot])} size='xl' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full mt-4 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md ' />
                </div>


                <p className={`${i18n.language == 'en' ? 'font-spartan font-normal' : 'font-rubik font-normal'} text-[15px] mt-10`}>{t('mainParkingLot')}</p>
                <Select
                    required={false}
                    value={mainParkingLot}
                    onChange={(e) => setMainParkingLot(e.target.value)}
                    className="mt-1 w-[18%] rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                    displayEmpty
                    sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}
                >
                    <MenuItem value='' disabled>
                        {t('selectparkinglot')}
                    </MenuItem>
                    {
                        mainParkingLotconfig?.options?.map((option, index) => {
                            return (
                                <MenuItem value={option?._id ? option?._id : option} key={index} sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}>
                                    {option?.name}
                                </MenuItem>
                            )
                        })
                    }
                </Select>
                <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[11px] pt-1 ${(inputErr && mainParkingLot == '') ? 'visible' : 'invisible'}`}>{t('fillalert')}</p>

                <div className='flex  mb-10  mt-8 items-center justify-center'>
                    <button
                        type='submit'
                        className={`bg-transparent transition-all delay-100 hover:bg-appSeaGreen hover:text-appWhite w-[204px] h-[59px] text-appSeaGreen border-2 border-appSeaGreen  rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-bold font-spartan' : 'font-rubik font-medium'} cursor-pointer `}
                    >
                        {t('createuser')}
                    </button>
                </div>
            </form >

            {showCalender && <div className='absolute z-20 top-0 left-0 h-full w-full flex items-center justify-center bg-black bg-opacity-50'>
                <div className='bg-white  rounded-2xl py-1'>
                    <div className='px-2'>
                        <h3 className={`${i18n.language == 'en' ? 'font-spartan ' : 'font-rubik'} font-normal text-[22px]`}>{moment(formatedDate)?.format('MMM DD')}</h3>
                    </div>
                    <Calendar
                        dir='ltr'
                        showMonthAndYearPickers
                        minValue={now()}
                        value={selectedDate}
                        onChange={setSelectedDate}
                    />
                    <div className='flex items-center justify-center gap-3 my-1'>
                        <div onClick={() => (setShowCalender(false), setCreateUser())} className='border-2 border-appnewdarkgreen h-[32px] rounded-full flex items-center justify-center cursor-pointer'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[14px]' : 'font-rubik text-[20px]'} font-medium  px-6 text-center text-appnewdarkgreen`}>
                                {t('guestcalendercancel')}
                            </p>
                        </div>
                        <div onClick={() => setShowCalender(false)} className='bg-appnewdarkgreen rounded-full h-[32px] flex items-center justify-center cursor-pointer'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[14px]' : 'font-rubik text-[20px]'} font-medium  px-6 text-center text-white`}>
                                {t('guestcalenderApproval')}
                            </p>
                        </div>
                    </div>
                </div>
            </div>}

        </>
    )
}

export default CreateUser