import React, { useEffect, useRef, useState } from 'react'
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import i18n from '../../i18n';
import { useTranslation } from 'react-i18next';
import { useSelector } from 'react-redux';
import Image from 'next/image';
import { svgImages } from '@/utilities/utils';
import moment from 'moment';




function OccupancyList({ tableHeader, Details, height, sorting, guest = false }) {
    const { t } = useTranslation()
    const { loader } = useSelector(state => state.user)
    const tableHeaderRef = useRef(null);
    const [marginTop, setMarginTop] = useState(tableHeaderRef.current?.clientHeight && tableHeaderRef.current.clientHeight)
    const [activeSorting, setActiveSorting] = useState(null)

    useEffect(() => {
        const headerHeight = tableHeaderRef.current.clientHeight;
        setMarginTop(headerHeight)
    }, [i18n.language, tableHeaderRef, Details,guest])

    useEffect(() => {
        const handleResize = () => {
            if (tableHeaderRef.current) {
                const headerHeight = tableHeaderRef.current.clientHeight;
                setMarginTop(headerHeight)
            }
        };

        window.addEventListener('resize', handleResize);

        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);

    const slotImage = (status, type, isFrozen) => {
        if (isFrozen) {
            return { style: "bg-appDarkGrey rounded-sm text-appWhite" }
        }

        if (status == 'reserved') {
            return { style: "border-2 border-appNewRed" }
        } else if (status == 'designated-not-released') {
            return { style: "bg-appNewRed" }
        } else {
            return { style: "border-2 border-appNewGreen" }
        }

    }


    return (
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: height,
            '&::-webkit-scrollbar': {
                width: '6px',
                backgroundColor: 'transparent',
            },
            '&::-webkit-scrollbar-thumb': {
                backgroundColor: '#737373',
                borderRadius: '3px',
            },
            '&::-webkit-scrollbar-track': {
                backgroundColor: 'transparent',
                marginTop: `${marginTop}px`
            },
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif'
                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: i18n.language == 'en' ? 700 : 500,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif',
                },
            }}
                stickyHeader aria-label="simple table">
                <TableHead >
                    <TableRow ref={tableHeaderRef}>
                        {
                            tableHeader.map((head, index) => {
                  
                                return (
                                    <TableCell className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} `} key={index} align='center'>
                                        <div
                                       className={`flex ${guest ?  '' : (index === 0 || index === 1 ? 'justify-center' : 'justify-start') } gap-1`}
                                    >
                                        <p className={`${i18n.language === 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[15px] flex items-end`}>{head?.title}</p>
                                        {head?.id && <Image  alt='sortIcon' onClick={() => head?.id && (sorting(head), setActiveSorting(index))} src={activeSorting == index ? svgImages.sort_up : svgImages.sortIcon} className='cursor-pointer' />}
                                    </div></TableCell>
                                )
                            })
                        }
                    </TableRow>
                </TableHead>
                <TableBody>
                    {Details?.map((spot,index) => {
                        return (
                            <TableRow
                                key={index}
                                sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                            >
                                <TableCell style={{ verticalAlign: 'top' }} align={ guest ? i18n.language == 'en'? "left": "right":"center"}>{guest ? (spot?.firstName ? spot?.firstName : '-') : (spot?.level?.name ? spot?.level?.name : '-')}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={ guest ? i18n.language == 'en'? "left": "right":"center"}>{guest ? (spot?.phoneNumber?.number ? spot?.phoneNumber?.number : '-') : (spot?.parkingCode ? spot?.parkingCode : '-')}</TableCell>
                                <TableCell style={{ verticalAlign: 'top', width: i18n.language == 'en' && '20%' }} align={`${i18n.language == 'en'? "left" : "right"}`}> {guest ? (spot?.vehicles?.length > 0 ? spot?.vehicles?.map((vehicle, index) => {
                                    return (
                                        <div key={index}>
                                            <p>{vehicle?.registration}</p>
                                            <br />
                                        </div>
                                    )
                                }) : '-') : <div ><p className={`${slotImage(spot?.status, spot?.spotType, spot?.isPermanent).style} inline px-2`}>{(spot?.isPermanent || spot?.status) ? spot?.isPermanent ? t('locked') : t(spot?.status) : '-'}</p></div>}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{guest ? (spot?.disabled ? <div className='flex items-center justify-start gap-1'>
                                    <p>{t('UserTableYes')}</p>
                                    <Image alt='disabledIcon' className='w-5 h-5' src={svgImages.disableNewUserTable} />
                                </div> : t('UserTableNo')) : (spot?.spotType ? t(spot?.spotType) : '-')}</TableCell>
                                {guest && <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{spot?.electricCharging  ? <div className='flex items-center justify-start'>
                                    <Image alt='electric icon' height={24} width={24} src={svgImages.electricNewUserTable} />
                                </div> : ''}</TableCell> }
                                <TableCell style={{ verticalAlign: 'top' }}align={`${i18n.language == 'en'? "left" : "right"}`}>{guest ? (spot?.designatedParkingSpot?.length > 0 ? spot?.designatedParkingSpot?.map((designatedSpot, index) => {
                                    return (
                                        <div key={index}>
                                            <p>{designatedSpot?.parkingCode}</p>
                                            <br />
                                        </div>
                                    )
                                }) : '-') : (spot?.designatedTo?.firstName ? spot?.designatedTo?.firstName : '-')}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{guest ? (spot?.createdAt ? moment(spot?.createdAt).format('DD/MM/YY') : '-') : (spot?.reservedBy?.firstName ? spot?.reservedBy?.firstName : '-')} </TableCell>
                                {!guest && <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{spot?.reservedBy || spot?.designatedTo ? spot?.reservedBy?.phoneNumber?.number || spot?.designatedTo?.phoneNumber?.number : '-'} </TableCell>}
                                {!guest && <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language == 'en'? "left" : "right"}`}>{spot?.reservedBy || spot?.designatedTo ? spot?.reservedBy?.vehicles?.[0]?.registration || spot?.designatedTo?.vehicles?.[0]?.registration : '-'} </TableCell>}
                            </TableRow>

                        )
                    }

                    )}
                </TableBody>
            </Table>
        </TableContainer>
    )
}

export default OccupancyList