import React, { useEffect, useRef, useState } from 'react'
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import dynamic from 'next/dynamic'
import Link from 'next/link';
import i18n from '../../i18n';
import { useTranslation } from 'react-i18next';
import { useSelector } from 'react-redux';



const FontIcon = dynamic(() => import('./FontIcon'), { ssr: false })



function ParkingLotsList({ tableHeader, Details }) {
    const { t } = useTranslation()
    const { parkingLots } = useSelector(state => state.user)
    const tableHeaderRef = useRef(null);
    const [marginTop, setMarginTop] = useState(tableHeaderRef.current?.clientHeight && tableHeaderRef.current.clientHeight)

    useEffect(() => {
        const headerHeight = tableHeaderRef.current.clientHeight;
        setMarginTop(headerHeight)
    }, [i18n.language, tableHeaderRef, Details, parkingLots])
    useEffect(() => {
        const handleResize = () => {
            if (tableHeaderRef.current) {
                const headerHeight = tableHeaderRef.current.clientHeight;
                setMarginTop(headerHeight)
            }
        };

        window.addEventListener('resize', handleResize);

        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);

    return (
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: '75vh',
            '&::-webkit-scrollbar': {
                width: '6px',
                backgroundColor: 'transparent',
            },
            '&::-webkit-scrollbar-thumb': {
                backgroundColor: '#737373',
                borderRadius: '3px',
            },
            '&::-webkit-scrollbar-track': {
                backgroundColor: 'transparent',
                marginTop: `${marginTop}px`
            },
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif'
                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: i18n.language == 'en' ? 700 : 500,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif',
                },
            }}
                stickyHeader aria-label="simple table">
                <TableHead >
                    <TableRow ref={tableHeaderRef}>
                        {
                            tableHeader.map((head, index) => {
                                return (
                                    <TableCell className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} `} key={index} align='center'>{head?.title}</TableCell>
                                )
                            })
                        }
                    </TableRow>
                </TableHead>
                <TableBody>
                    {Details.map((user, index) => (
                        <TableRow
                            key={index}
                            sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                        >
                            <TableCell align="center">{user?.name}</TableCell>
                            <TableCell align="center">{user?.regular}</TableCell>
                            <TableCell align="center">{user?.electric}</TableCell>
                            <TableCell align="center">{user?.designated}</TableCell>
                            <TableCell align="center">{user?.disabled}</TableCell>
                            <TableCell align="center">{user?.maxReservationDistance ? `${user?.maxReservationDistance} ${t('km')}` : '-'}</TableCell>
                            <TableCell align="center">{user?.allotmentMethod == 'random' ? 'Random' : user?.allotmentMethod == 'manual' ? 'Manual' : t('userselected')}</TableCell>
                            <TableCell>
                                <Link href={`/editParkingLots?data=${JSON.stringify(user)}`} as="/editParkingLots" >
                                    <FontIcon iconname="fa-solid fa-pen" size="sm" className='text-appLightGrey mt-0 hover:text-appSeaGreen hover:cursor-pointer' />
                                </Link>
                            </TableCell>
                            {/* <TableCell>
                                <Link href={`/parkingLotOccupancy?data=${JSON.stringify(user)}`} as={'/parkingLotOccupancy'} >
                                    <FontIcon iconname="fa-solid fa-bookmark" size="sm" className='text-appLightGrey mt-0 hover:text-appSeaGreen hover:cursor-pointer' />
                                </Link>
                            </TableCell> */}
                        </TableRow>
                    ))}
                </TableBody>
            </Table>
        </TableContainer>
    )
}

export default ParkingLotsList