import React, { useEffect, useRef, useState } from 'react'
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import dynamic from 'next/dynamic';
import i18n from '../../i18n';
import Link from 'next/link';
import moment from 'moment';

const FontIcon = dynamic(() => import('./FontIcon'), { ssr: false })


function ShabatList({ tableHeader, Details, handleModal, parkingLots }) {

    const tableHeaderRef = useRef(null);
    const [marginTop, setMarginTop] = useState(tableHeaderRef.current?.clientHeight && tableHeaderRef.current.clientHeight)


    useEffect(() => {
        const headerHeight = tableHeaderRef.current.clientHeight;
        setMarginTop(headerHeight)
    }, [i18n.language, tableHeaderRef, Details])

    useEffect(() => {
        const handleResize = () => {
            if (tableHeaderRef.current) {
                const headerHeight = tableHeaderRef.current.clientHeight;
                setMarginTop(headerHeight)
            }
        };

        window.addEventListener('resize', handleResize);

        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);

    return (
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: '75vh',
            '&::-webkit-scrollbar': {
                width: '6px',
                backgroundColor: 'transparent',
            },
            '&::-webkit-scrollbar-thumb': {
                backgroundColor: '#737373',
                borderRadius: '3px',
            },
            '&::-webkit-scrollbar-track': {
                backgroundColor: 'transparent',
                marginTop: `${marginTop}px`
            },
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300,
                    width: '120px',
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif'

                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: i18n.language == 'en' ? 700 : 500,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif',
                },
            }}
               stickyHeader aria-label="simple table">
                <TableHead >
                    <TableRow ref={tableHeaderRef}>
                        {
                            tableHeader.map((head, index) => {
                                return (
                                    <TableCell className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}`} key={index} align='center'>{head?.title}</TableCell>
                                )
                            })
                        }
                    </TableRow>
                </TableHead>
                <TableBody>
                    {Details.map((holiday, index) => {
                        return (
                            <TableRow
                                key={index}
                                sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                            >
                                <TableCell style={{ verticalAlign: 'top' }} align="center">{holiday?.name ? holiday?.name : '-'}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align="center">{holiday?.startDate ? moment.utc(holiday?.startDate).format('DD/MM/YYYY HH:mm') : '-'}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align="center">{holiday?.endDate ? moment.utc(holiday?.endDate).format('DD/MM/YYYY HH:mm') : '-'}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align='center'>
                                    <Link href={`/editHoliday?data=${JSON.stringify(holiday)}`} as="/editHoliday" >
                                        <FontIcon iconname="fa-solid fa-pen" size="sm" className='text-appLightGrey mt-0 hover:text-appSeaGreen hover:cursor-pointer' />
                                    </Link>
                                </TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align="center">{<FontIcon handleClick={() => handleModal(holiday?._id)} iconname="fa-solid fa-trash-can" size="sm" className='text-appLightGrey  hover:text-appSeaGreen hover:cursor-pointer' />}   </TableCell>
                            </TableRow>
                        )
                    })
                    }
                </TableBody>
            </Table>
        </TableContainer>
    )
}

export default ShabatList


