import React, { useEffect, useRef, useState } from 'react'
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import dynamic from 'next/dynamic';
import { useRouter } from 'next/router';
import Link from 'next/link';
import moment from 'moment';
import i18n from '../../i18n';
import { useSelector, useDispatch } from 'react-redux';
import { getCorrectDateTime, svgImages } from '@/utilities/utils';
import Image from 'next/image';
import { t } from 'i18next';


const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


function UserDetailsList({ height, setDeleteUserModal, sorting, tableHeader, Details }) {
    const tableHeaderRef = useRef(null);
    const { allUsers } = useSelector(state => state.user)
    const [marginTop, setMarginTop] = useState(tableHeaderRef.current?.clientHeight && tableHeaderRef.current.clientHeight)
    const [activeSorting, setActiveSorting] = useState(null)

    const handleDeleteUser = (user) => {
        setDeleteUserModal(user)
    }

    useEffect(() => {
        const headerHeight = tableHeaderRef.current.clientHeight;
        setMarginTop(headerHeight)
    }, [i18n.language, tableHeaderRef, Details, allUsers])

    useEffect(() => {
        const handleResize = () => {
            if (tableHeaderRef.current) {
                const headerHeight = tableHeaderRef.current.clientHeight;
                setMarginTop(headerHeight)
            }
        };

        window.addEventListener('resize', handleResize);

        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);


    return (
        <TableContainer sx={{
            boxShadow: 'none',
            maxHeight: height,
            '&::-webkit-scrollbar': {
                width: '6px',
                backgroundColor: 'transparent',
            },
            '&::-webkit-scrollbar-thumb': {
                backgroundColor: '#737373',
                borderRadius: '3px',
            },
            '&::-webkit-scrollbar-track': {
                backgroundColor: 'transparent',
                marginTop: `${marginTop}px`
            },
        }} component={Paper}>
            <Table sx={{
                minWidth: 650,
                '& th, & td': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000',
                    fontSize: '14px',
                    fontWeight: 300,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif'
                },
                '& th': {
                    borderBottom: '1px solid #4EB9B1',
                    color: '#000000',
                    fontSize: '15px',
                    fontWeight: i18n.language == 'en' ? 700 : 500,
                    fontFamily: i18n.language == 'en' ? 'Spartan,sans-serif' : 'Rubik,sans-serif',
                },
            }}
                stickyHeader aria-label="simple table">
                <TableHead >
                    <TableRow ref={tableHeaderRef}>
                        {
                            tableHeader.map((head, index) => {
                                return (
                                    <TableCell key={index} align={`${i18n.language === 'en' ? "left":"right"}`} className={`${i18n.language === 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-[15px] flex items-center`}>
                                        <div
                                            className='flex justify-start gap-1'
                                        >
                                            <p className={`${i18n.language === 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} ${index === 2 && i18n.language === 'en' ? "pl-5": "pr-5"} text-[15px] flex items-center`}>{head?.title}</p>
                                            {head?.id && <Image  alt='sortIcon' onClick={() => head?.id && (sorting(head), setActiveSorting(index))} src={activeSorting == index ? svgImages.sort_up                                : svgImages.sortIcon} className='cursor-pointer' />}
                                        </div>
                                    </TableCell>
                                )
                            })
                        }
                    </TableRow>
                </TableHead>
                <TableBody>
                    {Details.map((user, index) => {

                     
                        const filteredParkingSpots = user.designatedParkingSpot.filter(spot =>
                       user.parkingLots.find(lot => lot._id === spot.parkingLot._id)
                          );
                        

                        return (
                            <TableRow
                                key={index}
                                sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
                            >
                                <TableCell style={{ verticalAlign: 'top', color: user?.failedLoginAttempts == 3 ? '#959595' : '#000' }} align={`${i18n.language === 'en' ? "left":"right"}`} scope="row">
                                    {user?.firstName}
                                </TableCell>
                                <TableCell dir='ltr' style={{ verticalAlign: 'top', color: user?.failedLoginAttempts == 3 ? '#959595' : '#000' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.vehicles ? <div className='flex flex-col gap-1'>{user.vehicles.map((item, index) => (
                                    <p className='' key={index}>
                                        {item?.registration}<br />
                                    </p>
                                ))}</div> : '-'}</TableCell>
                                <TableCell colSpan={2} style={{ verticalAlign: 'top', color: user?.failedLoginAttempts == 3 ? '#959595' : '#000' }} align={`${i18n.language === 'en' ? "left":"right"}`}>
                                    {user?.parkingLots?.length > 0 ? (
                                        <div className='flex flex-col gap-1'>
                                            {user?.parkingLots?.map((item, index) => {
                                      
                                      const data  = filteredParkingSpots.find(items => items.parkingLot.name === item.name )
                                      
                                            return(
                                                <div className='flex bg-appNewLightBlue py-1' key={index}>
                                                    <span style={{ width:i18n.language === 'en' ? '55%' : "67%", paddingRight: i18n.language == 'en' ? 60 : 20, paddingLeft:15,  textAlign: i18n.language === 'en' ? 'left' : 'right' }}>{item?.name}</span>
                                                    <span style={{ width:i18n.language === 'en' ? '45%' : "33%", paddingRight: i18n.language == 'en' ? 35 : 20,   textAlign: i18n.language === 'en' ? 'left' : 'right' }}>{data?.parkingCode || '-'}</span>

                                                </div>
                                            )})}
                                        </div>
                                    ) : '-'}
                                </TableCell>
                                {/* <TableCell colSpan={2} style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.parkingLots?.length > 0 ? <div className='flex flex-col gap-1 '>{user?.parkingLots?.map((item,index) => (
                                    <p className='bg-slate-400' key={index}>
                                        {item?.name}<br />
                                    </p>
                                ))}</div> : '-'}</TableCell> */}
                                {/* <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.designatedParkingSpot.length > 0 ? <div className='flex flex-col gap-1'>{user?.designatedParkingSpot?.map((spot,index) => (
                                    <p className='' key={index}>
                                        {spot?.parkingCode}<br />
                                    </p>
                                ))}</div> : '-'}</TableCell> */}
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.electricCharging ? <div className='flex items-center justify-start'>
                                    <Image alt='electric icon' height={24} width={24} src={svgImages.electricNewUserTable} />
                                </div> : ''}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.disabled ? <div className='flex items-center justify-start'>
                                    <Image alt='disabled icon' height={24} width={24} src={svgImages.disableNewUserTable} />
                                </div> : ''}</TableCell>
                                <TableCell style={{ verticalAlign: 'top', color: user?.failedLoginAttempts == 3 ? '#959595' : '#000' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.phoneNumber?.number}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.failedLoginAttempts < 3 ? <div className='flex items-center justify-start gap-1'>
                                    <div className='w-3 h-3 rounded-md bg-appParrotGreen' />
                                    <p>{t('newDesignActive')}</p>
                                </div> : <div className='flex items-center justify-start gap-1'>
                                    <Image alt='lockedIcon' height={18} width={12} src={svgImages.lockedUp} />
                                    <p>{t('newDesignInactive')}</p>
                                </div>}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }} align={`${i18n.language === 'en' ? "left":"right"}`}>{user?.firstLoginDate ? <div className='flex items-center justify-start'>
                                    <Image alt='loginicon' height={24} width={24} src={svgImages.firstLoginTick} />
                                </div>
                                    : ' '}</TableCell>
                                <TableCell style={{ verticalAlign: 'top' }}>
                                    <Link href={`/editUser?data=${JSON.stringify(user)}`} as="/editUser" >
                                        <FontIcon iconname="fa-solid fa-pen" size="sm" className='text-appLightGrey mt-0 invert hover:filter-invert-sepia-saturate-hue hover:cursor-pointer' />
                                    </Link>
                                </TableCell>
                                <TableCell style={{ verticalAlign: 'top' }}>
                                    <FontIcon handleClick={() => handleDeleteUser(user)} iconname="fa-solid fa-trash-can" size="sm" className='text-appLightGrey mt-0 invert hover:filter-invert-sepia-saturate-hue hover:cursor-pointer' />
                                </TableCell>
                            </TableRow>
                        )
                    })}
                </TableBody>
            </Table>
        </TableContainer >
    )
}

export default UserDetailsList