import AdminUsersList from '@/components/AdminUsersList'
import CreateAdmin from '@/components/CreateAdmin'
import Modal from '@/components/model'
import Navbar from '@/components/navbar'
import { deleteAdmin, getAllAdmins, getParkingLots } from '@/store/userReducer'
import { IMAGES, svgImages } from '@/utilities/utils'
import dynamic from 'next/dynamic'
import Image from 'next/image'
import React, { useEffect, useState } from 'react'
import { useSelector, useDispatch } from 'react-redux';
import Loader from './Loader'
import { useRouter } from 'next/router'
import { useTranslation } from 'react-i18next'
import ToggleLanguageButton from '@/components/ToggleLanguageButton'
import i18n from '../../i18n'



const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })

function AdminUsers() {
  const { t } = useTranslation();
  const { allAdmins, loader, adminData, parkingLots } = useSelector(state => state.user)
  const dispatch = useDispatch()
  const router = useRouter()
  const [adminId, setAdminId] = useState('')
  const [deleteAdminModal, setDeleteAdminModal] = useState(false)
  const [createAdmin, setCreateAdmin] = useState(false)

  const [tableHeader, setTableHeader] = useState(
    [
      { title: t('adminsName') },
      { title: t('parkinglot') },
      { title: t('phonenmbr') },
      { title: t('email') },
      { title: ' ' },

    ]
  )

  const handleDelete = (id) => {
    dispatch(deleteAdmin({ id: id, token: adminData?.token }))
    setDeleteAdminModal(false)
  }

  const handleDeleteAdmin = (id) => {
    setAdminId(id)
    setDeleteAdminModal(!deleteAdminModal)
  }

  useEffect(() => {
    if (adminData?.token == undefined) {
      setTimeout(() => {
        router.push('/')
      }, 1000);
    } else if (adminData?.token) {
      dispatch(getAllAdmins({ token: adminData?.token }))
    }
  }, [adminData])

  useEffect(() => {
    if (parkingLots?.length == 0) {
      dispatch(getParkingLots({ token: adminData?.token, currentAdmin: adminData?.admin?._id }))
    }
  }, [parkingLots])


  useEffect(() => {
    setTableHeader(
      [
        { title: t('adminsName') },
        { title: t('parkinglot') },
        { title: t('phonenmbr') },
        { title: t('email') },
        { title: ' ' },
      ]
    )
  }, [i18n.language])

  if (adminData?.token == undefined) {
    return <Loader />
  }

  return (
    <>
      <Navbar active='admin'>
        {loader && <Loader />}
        {!createAdmin ? <>
          <div className='flex flex-row items-center justify-between mt-8 mx-12'>
            <h1 className={`${i18n.language == 'en' ? "font-spartan font-bold " : "font-rubik font-medium"} text-[30px]`}>{t('adminscreentitle')}</h1>
            <FontIcon handleClick={() => setCreateAdmin(true)} size='xl' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md ' />
          </div>
          <div className='max-w-full  rounded-2xl my-5 mx-5 shadow-xl pb-8' >
            <div className=' mt-10 mx-10'>
              <AdminUsersList parkingLots={parkingLots?.parkingLots} handleModal={handleDeleteAdmin} tableHeader={tableHeader} Details={allAdmins?.admins ? allAdmins?.admins : []} />
            </div>
          </div>
        </> : <CreateAdmin setCreateAdmin={setCreateAdmin} />}
      </Navbar>


      <Modal isOpen={deleteAdminModal} onClose={setDeleteAdminModal}>
        <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
          <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
        </div>
        <Image onClick={() => { setDeleteAdminModal(false) }} className={`mt-5 mx-3 ${i18n.language == 'he' && 'transform rotate-180'} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

        <div className='w-[430px]'>
          <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-center text-[18px] mt-4`}>
            {t('deleteadminmodel')}

          </p>
        </div>
        <div className='flex   mt-8 items-center justify-center'>
          <button
            onClick={() => handleDelete(adminId)}
            className={`bg-transparent w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}   cursor-pointer `}
          >
            {t('accept')}
          </button>
        </div>
        <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[11px] w-[299px] mx-auto pt-[10px] pb-[19px]`}>{t('deleteadminbelowwarning')}</p>
      </Modal>
    </>
  )
}

export default AdminUsers