import Navbar from '@/components/navbar'
import React, { useEffect, useState } from 'react'
import dynamic from 'next/dynamic'
import MuiCheckbox from '@/components/CheckBox'
import Time from '@/components/Time'
import moment from 'moment';
import { useSelector, useDispatch } from 'react-redux';
import { createAnnouncement, deleteSingleAnnouncement, getAllAnnouncement, getParkingLots } from '@/store/userReducer'
import Loader from './Loader'
import { useRouter } from 'next/router'
import { useTranslation } from 'react-i18next'
import i18n from '../../i18n'
import ToggleLanguageButton from '@/components/ToggleLanguageButton'
import Modal from '@/components/model'
import { IMAGES, svgImages } from '@/utilities/utils'
import Image from 'next/image'
import AnnounementList from '@/components/AnnouncementList'


const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


const CreateAnnouncement = () => {
  const { t } = useTranslation()
  const { adminData, loader, parkingLots, allAnnouncements } = useSelector(state => state.user)
  const dispatch = useDispatch()
  const router = useRouter()
  const [announcementCreate, setAnnouncementCreate] = useState(false)
  const [deleteAnnouncement, setDeleteAnnouncement] = useState(false)
  const [announcementId, setAnnouncementId] = useState(null)
  const [selectedCheckboxes, setSelectedCheckboxes] = useState([]);
  //start date
  const [startselectedDate, setStartSelectedDate] = useState('');
  const [startHour, setstartHour] = useState(1);
  const [startMinute, setstartMinute] = useState(0);
  const [startPeriod, setstartPeriod] = useState('AM');
  const setStartTime = () => {
    setstartHour(1)
    setstartHour(0)
    setstartPeriod('AM')
  }
  //

  //end date
  const [endSelectedDate, setEndSelectedDate] = useState('');
  const [endHour, setEndHour] = useState(1);
  const [endMinute, setEndMinute] = useState(0);
  const [endPeriod, setEndPeriod] = useState('AM');
  const setEndTime = () => {
    setEndHour(1)
    setEndMinute(0)
    setEndPeriod('AM')
  }
  //

  const [text, setText] = useState('');
  const maxCharacters = 300;


  //start date  
  const handlestartHourChange = (e) => {
    setstartHour(parseInt(e.target.value, 10));
  };

  const handlestartMinuteChange = (e) => {
    setstartMinute(parseInt(e.target.value, 10));
  };

  const handlestartPeriodChange = (e) => {
    setstartPeriod(e.target.value);
  };

  const togglestartPeriod = () => {
    setstartPeriod((prevstartPeriod) => (prevstartPeriod === 'AM' ? 'PM' : 'AM'));
  };
  //


  //end date
  const handleEndHourChange = (e) => {
    setEndHour(parseInt(e.target.value, 10));
  };

  const handleEndMinuteChange = (e) => {
    setEndMinute(parseInt(e.target.value, 10));
  };

  const handleEndPeriodChange = (e) => {
    setEndPeriod(e.target.value);
  };

  const toggleEndPeriod = () => {
    setEndPeriod((prevstartPeriod) => (prevstartPeriod === 'AM' ? 'PM' : 'AM'));
  };
  //

  const handleCheckboxChange = (Id) => {
    const isSelected = selectedCheckboxes.includes(Id);
    if (!isSelected) {
      setSelectedCheckboxes((prevSelected) => [...prevSelected, Id]);
    } else {
      setSelectedCheckboxes((prevSelected) =>
        prevSelected.filter((id) => id !== Id)
      );
    }
  };


  const handleChange = (event) => {
    setText(event.target.value);
  };

  const clearStates = () => {
    setSelectedCheckboxes([])
    setText('')
    setStartTime()
    setEndTime()
    setEndSelectedDate('')
    setStartSelectedDate('')
  }

  const handleAnouncement = () => {
    const startTime = moment(`${startHour} ${startMinute} ${startPeriod} ${startselectedDate}`, 'h m A YYYY-MM-DD').format('YYYY-MM-DDTHH:mm:ss.SSS[Z]');
    const EndTime = moment(`${endHour} ${endMinute} ${endPeriod} ${endSelectedDate}`, 'h m A YYYY-MM-DD').format('YYYY-MM-DDTHH:mm:ss.SSS[Z]');
    if (selectedCheckboxes.length > 0 && text != '' && startTime && EndTime) {
      dispatch(createAnnouncement({ clearStates: () => clearStates(), successModel: () => setAnnouncementCreate(true), token: adminData?.token, data: { parkingLots: selectedCheckboxes, startDate: startTime, endDate: EndTime, title: 'Announement', content: text } }))
    }
  }

  const [tableHeader, setTableHeader] = useState([
    { title: t('parkinglot') },
    { title: t('start') },
    { title: t('end') },
    { title: t('announcementtext') },
    { title: ' ' },
  ])

  useEffect(() => {
    setTableHeader(
      [
        { title: t('parkinglot') },
        { title: t('start') },
        { title: t('end') },
        { title: t('announcementtext') },
        { title: ' ' },
      ]
    )
  }, [i18n.language])

  const handleDeleteAnnouncement = (id) => {
    setAnnouncementId(id)
    setDeleteAnnouncement(true)
  }

  const handleDelete = (id) => {
    dispatch(deleteSingleAnnouncement({ id: id }))
    setDeleteAnnouncement(false)

  }

  useEffect(() => {
    if (parkingLots?.parkingLots?.length == 1) {
      setSelectedCheckboxes([parkingLots?.parkingLots[0]?._id])
    }
  }, [parkingLots?.parkingLots])

  useEffect(() => {
    if (adminData?.token == undefined) {
      setTimeout(() => {
        router.push('/')
      }, 1000);
    } else {
      dispatch(getParkingLots({ token: adminData?.token, currentAdmin: adminData?.admin?._id }))
      dispatch(getAllAnnouncement())
    }
  }, [adminData])

  if (adminData?.token == undefined) {
    return <Loader />
  }


  return (
    <div>
      <Navbar active='announcement'>
        {loader && <Loader />}
        <div className='flex flex-row items-center justify-between mt-8 mx-12'>
          <h1 className={`${i18n.language == 'en' ? 'font-spartanfont-bold ' : 'font-rubik font-medium'}  text-[30px]`}>{t('createannoncement')}</h1>
          <FontIcon size='xl' iconname="fa-solid fa-xmark" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen  ' />
        </div>

        <div className='mx-[124px] mt-[46px]'>
          <h2 className={`${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[22px] text-appBlack`}>{t('chooseparkinglot')}</h2>
          <div className='mt-[30px] mx-5 max-h-48 overflow-hidden overflow-y-auto' >
            {parkingLots?.parkingLots?.map((parkingLot) => (
              <MuiCheckbox
                key={parkingLot?._id}
                label={parkingLot?.name}
                name={parkingLot?._id}
                checked={selectedCheckboxes.includes(parkingLot._id)}
                onChange={() => handleCheckboxChange(parkingLot?._id)}
              />
            ))}
          </div>
          <div className='flex items-center mt-[33px]'>
            <h1 className={`font-normal text-[22px] text-appGreyLight42 mx-[18px] ${i18n.language == 'he' ? 'w-[120px] font-rubik' : 'w-[240px] font-spartan'}  `}>{t('announcementstart')}</h1>
            <Time minute={startMinute} hour={startHour} period={startPeriod} handleHourChange={handlestartHourChange} togglePeriod={togglestartPeriod} handleMinuteChange={handlestartMinuteChange} />
            <input min={moment().format('YYYY-MM-DD')} value={startselectedDate} onChange={(e) => setStartSelectedDate(e.target.value)} type="date" className={`w-[30%] px-3 ml-[28px] border ${i18n.language == 'he' ? 'font-rubik' : "font-spartan"} rounded-md shadow-md border-appSeaGreen`} />
          </div>

          <div className='flex items-center mt-[33px]'>
            <h1 className={` font-normal text-[22px] text-appGreyLight42 mx-[18px] ${i18n.language == 'he' ? 'w-[120px] font-rubik' : 'w-[240px] font-spartan'} `}>{t('announcementend')}</h1>
            <Time minute={endMinute} hour={endHour} period={endPeriod} handleHourChange={handleEndHourChange} togglePeriod={toggleEndPeriod} handleMinuteChange={handleEndMinuteChange} />
            <input min={moment().format('YYYY-MM-DD')} value={endSelectedDate} onChange={(e) => setEndSelectedDate(e.target.value)} type="date" className={`w-[30%] px-3 ml-[28px] border ${i18n.language == 'he' ? 'font-rubik' : "font-spartan"}  rounded-md shadow-md border-appSeaGreen`} />
          </div>

          <div className='mx-20'>

            <h1 className={`${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[22px] text-appBlack mt-[30px] pb-2`}>{t('announcementtext')}</h1>

            <div className="w-[90%]">
              <textarea
                value={text}
                onChange={handleChange}
                maxLength={maxCharacters}
                rows={8}
                cols={50}
                className="w-full p-2 font-spartan font-normal shadow-lg rounded-[15px] resize-none focus:outline-none  "
              />
              <div className={`text-appLightGrey ${i18n.language == 'he' ? 'font-rubik' : 'font-spartan'}  font-normal text-[15px] text-right -mt-10 mx-5`}>
                {text.length}/{maxCharacters} {t('character')}
              </div>
            </div>
          </div>

        </div>

        <div className='flex   mt-8 items-center justify-center  pb-8'>
          <button
            onClick={() => handleAnouncement()}
            className={`bg-transparent w-[134px] h-[59px] text-appSeaGreen hover:bg-appSeaGreen hover:text-appWhite transition-all delay-75  border-2 border-appSeaGreen rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  cursor-pointer `}
          >
            {t('publish')}
          </button>
        </div>

        <div className='w-full h-[97%] px-12 pb-4'>
          <div className='w-full h-full'>
            <p className={`${i18n.language == 'en' ? 'font-spartanfont-bold ' : 'font-rubik font-medium'} text-[30px] mb-3`}>{t('announcements')}</p>
            <AnnounementList handleModal={handleDeleteAnnouncement} tableHeader={tableHeader} Details={allAnnouncements?.announcements ? allAnnouncements?.announcements : []} />
          </div>
        </div>

        <Modal isOpen={announcementCreate}>
          <div className='bg-appdarkgreen items-center rounded-t-lg flex justify-center py-6 '>
            <Image alt='warningimg' className='w-12 h-12 ' src={svgImages.maillighted} />
          </div>
          <div className='w-[430px] px-5'>
            <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-center text-[18px] mt-4`}>
              {t('createAnnouncement')}
            </p>
          </div>

          <div className='flex mb-10  mt-8 items-center justify-center'>
            <button
              onClick={() => setAnnouncementCreate(false)}
              className={`bg-transparent w-[134px] h-[59px] text-appdarkgreen border-2 border-appdarkgreen rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}   cursor-pointer `}
            >
              {t('accept')}
            </button>
          </div>
        </Modal>

        <Modal isOpen={deleteAnnouncement} onClose={setDeleteAnnouncement}>
          <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
            <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
          </div>
          <Image onClick={() => { setDeleteAnnouncement(false) }} className={`mt-5 mx-3 ${i18n.language == 'he' && 'transform rotate-180'} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

          <div className='w-[430px]'>
            <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-center text-[18px] mt-4`}>
              {t('deleteannouncementtext')}

            </p>
          </div>
          <div className='flex   mt-8 pb-4 items-center justify-center'>
            <button
              onClick={() => handleDelete(announcementId)}
              className={`bg-transparent w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}   cursor-pointer `}
            >
              {t('accept')}
            </button>
          </div>
        </Modal>

      </Navbar>

    </div>
  )
}

export default CreateAnnouncement