import { IMAGES, svgImages } from '@/utilities/utils'
import Image from 'next/image'
import React, { useEffect, useLayoutEffect, useRef, useState } from 'react'
import dynamic from 'next/dynamic'
import Navbar from '@/components/navbar'
import CreateUser from '@/components/CreateUser'
import { useSelector, useDispatch } from 'react-redux';
import { createMultipleUser, deleteUser, exportGuestUsers, exportmonitoringList, getAllGuestUsers, getAllMonitoringLots, getAllUsers, getOccupancyLots, getParkingLots, lotCount, uploadFile } from '@/store/userReducer'
import Loader from './Loader'
import { useRouter } from 'next/router'
import { useTranslation } from 'react-i18next'
import ToggleLanguageButton from '@/components/ToggleLanguageButton'
import i18n from '../../i18n'
import { useDebounce } from 'use-debounce';
import InputField from '@/components/InputField'
import Modal from '@/components/model'
import Pagination from '@mui/material/Pagination';
import Link from 'next/link'
import { setFrom, setOccupancyDropdownSelectedParkingLot } from '@/store/userSlice'
import OccupancyList from '@/components/OccupancyList'
import Single_MultipleSelectDropdown from '@/components/Single_MultipleSelectDropdown'



const PieChartWithCenterLabel = dynamic(() => import('../components/ChartComponent'), { ssr: false })
const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })



const Dashboard = () => {
    const { t } = useTranslation()
    const { loader, allUsers, lotsCount, adminData, parkingLots, occupancyLevelsSpots, allGuestUsers, occupancyDropdownSelectedParkingLot } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const router = useRouter()

    const [showCharts, setShowCharts] = useState(false)
    const [pagination, setPagination] = useState()
    const [createUser, setCreateUser] = useState(false)
    const [tabShow, setTabShow] = useState(false)
    const [dropdownOpen, setDropdownOpen] = useState(false)
    const [selectedParkingLot, setSelectedParkingLot] = useState(null)
    const [occupancyDetails, setOccupancyDetails] = useState([])
    const [deleteUserModal, setDeleteUserModal] = useState(false)
    const [deleteUserId, setDeleteUserId] = useState(null)
    const [users, setUsers] = useState(allUsers?.users ? allUsers?.users : [])
    const [searchUsers, setSearchUsers] = useState('')
    const [sortType, setSortType] = useState('dsc')
    const inputRef = useRef(null)
    // const [debouncedSearchTerm] = useDebounce(searchUsers, 700);
    const fileInputRef = useRef(null);
    const [userPage, setUserPage] = useState(1)

    const handleIconClick = () => {
        fileInputRef.current.click();
    };

    const handleFileChange = (e) => {
        const selectedFile = e.target.files[0];
        dispatch(uploadFile({
            usersFile: selectedFile,
            token: adminData?.token,
            userFileStatus: true,
            alert: (data) => alert(data),
            language: i18n.language == 'en' ? 'en' : 'heb',
            alertMsg: t('verifycsv')
        }))
    };

    const [tableHeader, setTableHeader] = useState(
        [
            { title: t('occupancyareaname'), id: 'level' },
            { title: t('occupancyparkingspotnumber'), id: 'parkingCode' },
            { title: t('occupancyparkingspotstatus'), id: 'status' },
            { title: t('occupancyparkingspottype'), id: 'spotType' },
            { title: t('occupancyspotdesignatedto'), id: 'firstName' },
            { title: t('occupancyspotoccupancy'), id: 'firstNameReservedBy' },
            { title: t('occupancyphonenumber'), id: 'phoneNumberDesignated' },
            { title: t('occupancyvehiclenumber'), id: 'registration' },

        ]
    )

    const [guestTableHeader, setGuestTableHeader] = useState([
        { title: t('guestname'), id: 'firstName' },
        { title: t('guestphonenumber'), id: 'phoneNumber' },
        { title: t('guestcarnumber'), id: 'registration' },
        { title: t('guestaccessible'), id: 'disabled' },
        { title: t('guestaccessible'), id: 'disabled' },
        { title: t('guestreservespot'), id: 'reserved' },
        { title: t('guestarivaldate'), id: 'created' },
    ])

    const handlePage = (clickedNumber) => {
        const updatedPagination = pagination.map((page) => ({
            number: page.number,
            active: page.number === clickedNumber,
        }));
        setPagination(updatedPagination);
        dispatch(lotCount({ token: adminData?.token, pagenumber: clickedNumber, limit: 4 }))
    }

    const newarr = (length) => {
        return Array.from({ length }, (_, index) => ({
            number: index + 1,
            active: index === 0,
        }));
    }

    const handleSorting = (item) => {
        setSortType(sortType == 'dsc' ? 'asc' : 'dsc')
        if (tabShow) {
            dispatch(getAllGuestUsers({
                params: {
                    page: 1, limit: 5000000, sort: sortType, sortBy: item?.id, parkingLot: selectedParkingLot?._id
                },
                noLoader: false
            }))
        } else {
            dispatch(getOccupancyLots({
                id: selectedParkingLot?._id,
                params: {
                    page: 1,
                    limit: 100000,
                    sort: sortType,
                    sortBy: item?.id,
                    search: ''
                },
            }))
        }
    }

    const handleDeleteUser = () => {
        setDeleteUserModal(false)
        dispatch(deleteUser({ token: adminData?.token, id: deleteUserId, notBack: true }))
    }

    const handleExportUser = () => {
        if (tabShow) {
            dispatch(exportGuestUsers())
        } else {
            dispatch(exportmonitoringList({ id: selectedParkingLot?._id }))
        }
    }

    const handleSearch = () => {
        let searchData;

        if (tabShow) {
            searchData = allGuestUsers?.users?.filter(guestUser => (
                guestUser?.firstName?.toLowerCase()?.includes(searchUsers) ||
                guestUser?.designatedParkingSpot?.some(spot => spot?.parkingCode?.toLowerCase()?.includes(searchUsers)) ||
                guestUser?.phoneNumber?.number?.includes(searchUsers) ||
                guestUser?.vehicles?.some(number => number?.registration?.toLowerCase()?.includes(searchUsers))
            ))
        } else {
            console.log("searchUsers",searchUsers)
            searchData = occupancyLevelsSpots?.parkingSpots?.filter(spot =>{
                return (
                spot?.level?.name?.toLowerCase()?.includes(searchUsers) ||
                spot?.designatedTo?.firstName.toLowerCase()?.includes(searchUsers) ||
                spot?.parkingCode?.toLowerCase()?.includes(searchUsers) ||
                spot?.designatedTo?.phoneNumber?.number?.includes(searchUsers) ||
                spot?.reservedBy?.phoneNumber?.number?.includes(searchUsers) ||
                spot?.designatedTo?.vehicles?.some(number => number?.registration?.toLowerCase()?.includes(searchUsers)) ||
                spot?.reservedBy?.vehicles?.some(number => number?.registration?.toLowerCase()?.includes(searchUsers))

            )})
        }

        setOccupancyDetails(searchData)
    }

    // useEffect(() => {
    //     if (debouncedSearchTerm) {
    //         inputRef.current.blur()
    //         dispatch(getAllUsers({
    //             token: adminData?.token, params: {
    //                 page: 1,
    //                 limit: 100000,
    //                 isAvailable: true,
    //                 search: debouncedSearchTerm.length == 0 ? "" : debouncedSearchTerm
    //             },
    //             noLoader: true,
    //             fromSearch: true,
    //             focus: () => { inputRef.current.focus() }
    //         }))
    //     }
    //     setUserPage(1)
    // }, [debouncedSearchTerm])

    useEffect(() => {
        setSearchUsers('')
        if (tabShow) {
            setOccupancyDetails(allGuestUsers?.users)
        } else {
            setOccupancyDetails(occupancyLevelsSpots?.parkingSpots)
        }
    }, [tabShow])

    useEffect(() => {
        setSelectedParkingLot(occupancyDropdownSelectedParkingLot ? occupancyDropdownSelectedParkingLot : parkingLots?.parkingLots?.[0])
    }, [parkingLots])

    useEffect(() => {
        if (tabShow) {
            setOccupancyDetails(allGuestUsers?.users)
        } else {
            setOccupancyDetails(occupancyLevelsSpots?.parkingSpots)
        }
    }, [occupancyLevelsSpots, allGuestUsers])

    useEffect(() => {
        setUsers(allUsers?.users)
        dispatch(setFrom(null))
    }, [allUsers])

    useEffect(() => {
        setTableHeader(
            [
                { title: t('occupancyareaname'), id: 'level' },
                { title: t('occupancyparkingspotnumber'), id: 'parkingCode' },
                { title: t('occupancyparkingspotstatus'), id: 'status' },
                { title: t('occupancyparkingspottype'), id: 'spotType' },
                { title: t('occupancyspotdesignatedto'), id: 'firstName' },
                { title: t('occupancyspotoccupancy'), id: 'firstNameReservedBy' },
                { title: t('occupancyphonenumber'), id: 'phoneNumberDesignated' },
                { title: t('occupancyvehiclenumber'), id: 'registration' },
            ]
        )
        setGuestTableHeader([
            { title: t('guestname'), id: 'firstName' },
            { title: t('guestphonenumber'), id: 'phoneNumber' },
            { title: t('guestcarnumber'), id: 'registration' },
            { title: t('guestaccessible'), id: 'disabled' },
            { title: t('userTableElectric') },
            { title: t('guestreservespot'), id: 'reserved' },
            { title: t('guestarivaldate'), id: 'created' },
        ])
    }, [i18n.language])

    useEffect(() => {
        if (lotsCount?.totalPages) {
            setPagination(newarr(lotsCount?.totalPages))
        }
    }, [lotsCount?.totalPages])

    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')

            }, 1000);
        } else if (adminData?.token) {
            if (!parkingLots) {
                dispatch(getParkingLots({ token: adminData?.token, currentAdmin: adminData?.admin?._id, noLoader: true }))
            }
            if (!lotsCount) {
                dispatch(lotCount({ token: adminData?.token, pagenumber: 1, limit: 4, noLoader: true }))
            }
        }
    }, [adminData])

    useEffect(() => {
        if (selectedParkingLot) {
            dispatch(getOccupancyLots({ id: selectedParkingLot?._id }))
            dispatch(getAllGuestUsers({
                params: {
                    page: 1, limit: 5000000, sort: 'asc', sortBy: 'created', parkingLot: selectedParkingLot?._id
                },
                noLoader: true
            }))
        }
    }, [selectedParkingLot])


    if (adminData?.token == undefined) {
        return <Loader />
    }

    return (
        <>
            <Navbar active='dashboard' >
                {loader && <Loader />}
                {!createUser ? <>
                    <div className='inline-flex items-center gap-2 mt-[27px] mx-[49px]'>
                        <FontIcon handleClick={() => setShowCharts(!showCharts)} iconname={`fa-solid fa-chevron-down`} className={`text-appBlack ${!showCharts && `${i18n.language == 'en' ? '-rotate-90' : 'rotate-90'} `}`} />
                        <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} select-none font-bold text-[30px] `}>{t('dashboard')}</h1>
                    </div>
                    {showCharts && <>
                        <div className='flex items-center justify-center gap-7 px-10 mt-[25px]'>
                            {
                                lotsCount?.counts?.map((lot, index) => {
                                    return (<Link href={`/monitoring?data=${JSON.stringify(lot?.parkingLot)}`} as={'/monitoring'} key={index} className='shadow-lg relative min-w-[237px] min-h-[186px] pb-4 px-5 bg-white rounded-md flex flex-col items-center justify-center'>
                                        <PieChartWithCenterLabel lot={lot} />
                                        <div className='absolute mt-7'>
                                            <Image alt='car' width={20} height={20} className='mx-auto mb-1' src={svgImages.boldcar} />
                                            <p className='font-spartan font-bold text-[18px]'>{lot.reserved}/{lot.total}</p>
                                        </div>
                                        <h2 className={`${i18n.language == 'he' ? 'font-rubik' : 'font-spartan'} text-center font-bold text-[25px] -mt-11`}>{lot?.parkingLot?.name}</h2>
                                    </Link>
                                    )
                                })
                            }
                        </div>

                        <div className='flex justify-center items-center gap-3 mt-[15px] mb-2'>
                            {
                                pagination?.map((page, index) => {
                                    return (
                                        <button onClick={() => { handlePage(page.number) }} key={index} className={`rounded-full ${page.active ? 'bg-appSeaGreen' : 'bg-appLightGrey'} text-appWhite font-spartan font-normal text-[14px]  text-center pt-0.5 w-[23px] h-[23px] `} > {page.number}</button>
                                    )
                                })
                            }
                        </div>
                    </>
                    }
                    <div className={`relative mx-5 ${!showCharts ? 'mt-5' : 'mt-1'}`}>
                        <InputField onKeyPress={(e) => {
                            if (e.key === 'Enter') {
                                handleSearch()
                            }
                        }} from='searchUser' inputRef={inputRef} value={searchUsers} onChange={e => {
                            setSearchUsers(e.target.value.toLowerCase());
                        }} />
                        <Image onClick={() => handleSearch()} alt='searchiconimg' width={48} height={48} className={`absolute top-[5px] cursor-pointer ${i18n.language == 'en' ? 'right-1' : 'left-1'}`} src={svgImages.searchUserIcon} />
                    </div>
                    <div className='max-w-full rounded-2xl mt-5 mx-5 shadow-[0px_4px_30px_10px_#00000015] mb-8 ' >
                        <div className='flex items-center justify-between mx-10 pt-[41px] '>
                            <div className='flex items-center gap-5 w-[100%]'>
                                <h1 onClick={() => setTabShow(false)} className={`${!tabShow ? 'text-appBlack border-b-2 border-appdarkgreen duration-150' : 'text-appdarkgreen font-normal hover:text-appdarkgreen duration-150'} ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-bold'} cursor-pointer text-[22px] pt-2 `}>{t('newDesignMonitoringText')}</h1>
                                <div className='flex items-center justify-center gap-5'>
                                    <h1 onClick={() => setTabShow(true)} className={`${tabShow ? 'text-appBlack border-b-2 border-appdarkgreen duration-150' : 'text-appdarkgreen font-normal hover:text-appdarkgreen duration-150'} ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-bold'} cursor-pointer text-[22px] pt-2`}>{t('newDesignGuestsText')}</h1>
                                    <div className='relative flex items-center justify-center group'>
                                        <FontIcon handleClick={() => setCreateUser(true)} size='xl' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full invert hover:invert-0 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md group-hover:text-opacity-100' />
                                        <p className={`${i18n.language == 'en' ? 'font-spartan -left-2' : 'font-rubik'} text-appWhite  text-[10px] absolute bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -top-14 invisible text-center group-hover:visible transition-opacity duration-300`}>{t('newdesignaddguestuser')}</p>
                                    </div>
                                </div>
                                <div className={`h-[56px] w-[21%] ${dropdownOpen ? 'bg-appnewdarkgreen duration-200' : 'bg-Lightbluegray duration-150'}  rounded-[28px] flex items-center justify-center relative`}>
                                    <Single_MultipleSelectDropdown selectedParkingLot={selectedParkingLot} setSelectedParkingLot={(parkingLot) => (setSelectedParkingLot(parkingLot), dispatch(setOccupancyDropdownSelectedParkingLot(parkingLot)))} parkingLots={parkingLots?.parkingLots || []} dropdownOpen={dropdownOpen} setDropdownOpen={() => { setDropdownOpen(!dropdownOpen) }} />
                                </div>
                            </div>
                            <div className='relative flex items-center justify-center group'>
                                <FontIcon handleClick={() => handleExportUser()} size='2xl' iconname="fa-solid fa-file-arrow-down" className='text-appLightGrey rounded-full invert hover:invert-0 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md' />
                                <p className={`${i18n.language == 'en' ? `font-spartan ${!tabShow ? '-left-7' : '-left-4'}` : `font-rubik ${!tabShow ? '-left-3' : '-left-5'}`} text-appWhite  text-[10px] absolute bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -top-14 invisible text-center group-hover:visible transition-opacity duration-300`}>{!tabShow ? t('exportmonitoring') : t('newdesignexportguestuser')}</p>
                            </div>
                        </div>
                        {/* {allUsers?.totalPages >= 2 && <div className='flex px-10 justify-end'>
                            <Pagination
                                dir='ltr'
                                count={allUsers?.totalPages}
                                page={userPage}
                                onChange={(e, value) => setUserPage(value)}
                                showFirstButton={userPage != 1}
                                showLastButton={allUsers?.totalPages != 0 && userPage != allUsers?.totalPages}
                                hideNextButton={allUsers?.totalPages == 0 || userPage == allUsers?.totalPages}
                                hidePrevButton={userPage == 1}
                                sx={{
                                    '& .MuiPaginationItem-page.Mui-selected': {
                                        backgroundColor: '#4EB9B1',
                                    },
                                }}
                            />
                        </div>} */}
                        <div className='mt-2 max-w-full mx-10'>
                            <OccupancyList guest={tabShow} height={!showCharts ? '60.7vh' : '33.5vh'} sorting={(item) => handleSorting(item)} tableHeader={!tabShow ? tableHeader : guestTableHeader} Details={selectedParkingLot ? (occupancyDetails || []) : []} />
                        </div>
                    </div>
                </> : <CreateUser selectedParkingLot={selectedParkingLot?._id} guestUser={true} setCreateUser={() => { setCreateUser(false) }} />
                }

                <Modal isOpen={deleteUserModal} onClose={setDeleteUserModal} >
                    <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
                        <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                    </div>
                    <Image onClick={() => setDeleteUserModal(false)} className={`mt-5 mx-3 ${i18n.language == 'he' && 'rotate-180 '} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

                    <div className='w-[450px]'>
                        <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-center text-[18px] mt-4 px-0`}>
                            {t('deleteUserModalText')}
                        </p>
                    </div>
                    <div className='flex  mt-8 items-center justify-center'>
                        <button
                            onClick={() => handleDeleteUser()}
                            className='bg-transparent mb-7 w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] font-bold font-spartan cursor-pointer '
                        >
                            {t('accept')}
                        </button>
                    </div>
                </Modal>
            </Navbar >
        </ >
    )
}

export default Dashboard