import InputField from '@/components/InputField'
import Navbar from '@/components/navbar'
import React, { useEffect, useState } from 'react'
import { useSelector, useDispatch } from 'react-redux';
import dynamic from 'next/dynamic'
import { InputLabel, MenuItem, Select } from '@mui/material';
import { useRouter } from 'next/router';
import { addNewParkingsSpot } from '@/store/userSlice';
import SpotParking from '@/components/SpotParking';
import { deleteParking, getAllAdmins, getParkingLotLevels, updateParkingLot, uploadFile, uploadImage } from '@/store/userReducer';
import Loader from './Loader';
import Modal from '@/components/model';
import { IMAGES, svgImages } from '@/utilities/utils';
import Image from 'next/image'
import { useTranslation } from 'react-i18next';
import i18n from '../../i18n';
import ToggleLanguageButton from '@/components/ToggleLanguageButton';

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


function editParkingLots({ route }) {
    const { t } = useTranslation()
    const { allAdmins, adminData, loader, parkingsSpots, parkingLevels, smsSendTime } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const router = useRouter()
    const [updateAccessMapFile, setUpdateAccessMapFile] = useState(false)
    const [updateAllotmentFile, setupdateAllotmentFile] = useState(false)
    const [newRow, setNewRow] = useState(false)
    const [updateAvatar, setUpdateAvatar] = useState(false)
    const [deleteLotModel, setDeleteLotModel] = useState(false)
    const [parkingSpots, setParkingSpots] = useState([])

    const data = router.query.data ? JSON.parse(router.query.data) : null

    const [parkinglotDetail, setparkinglotDetail] = useState({
        name: data ? data?.name : '',
        designated: data ? data?.designated : 0,
        accessMapFile: data ? data?.accessMapFile : null,
        regular: data ? data?.regular : 0,
        maxReservationDistance: data ? data?.maxReservationDistance : 0,
        admins: data?.admins ? data?.admins : [],
        allotmentFile: data ? data?.allotmentFile : null,
        electric: data ? data?.electric : 0,
        allotmentMethod: data ? data?.allotmentMethod : '',
        electricChargingTimeLimit: data?.chargingTimeLimit ? `${data?.chargingTimeStart}-${data?.chargingTimeEnd}` : '',
        parkingLotImageFile: null,
        location: {
            name: data ? data?.location?.name : '',
            latitude: data && data?.location?.latitude,
            longitude: data && data?.location?.longitude
        },
        avatar: data ? data?.avatar : null,
        chargingTimeLimit: data?.chargingTimeLimit ? true : false,
        chargingTimeStart: data?.chargingTimeStart ? data?.chargingTimeStart : "",
        chargingTimeEnd: data?.chargingTimeEnd ? data?.chargingTimeEnd : "",
        smsSendTime: data?.messageSendTime ? data?.messageSendTime : '',
        reservationTime: data?.reservationTime ? data?.reservationTime : '',
        messageSendTime: data?.messageSendTime ? data?.messageSendTime : '',
        messageSendTimeOfDay: data?.messageSendTimeOfDay ? data?.messageSendTimeOfDay : '',
        designatedReservationDuration: data?.designatedReservationDuration ? data?.designatedReservationDuration : '',
    });

    const adminOptions = allAdmins?.admins?.map(admin => ({ label: admin.firstName, value: admin._id }))?.concat({
        label: adminData?.admin?.firstName,
        value: adminData?.admin?._id
    });
    // console.log('admins ====', adminData?.admin?.role)


    const times = Array.from({ length: 24 / 2 }, (_, index) => {
        const startHour = (index * 2).toString().padStart(2, '0');
        const endHour = ((index * 2) + 2).toString().padStart(2, '0');
        return `${startHour}:00-${endHour}:00`;
    });

    const formConfig = [
        { key: 'name', label: 'Name', type: 'text' },
        { key: 'location', label: 'Address', type: 'text' },
        { key: 'smsSendTime', label: 'SMS Send Time', type: 'time', },
        { key: 'designatedReservationDuration', label: 'designated reservation duration', type: 'text', },
        { key: 'accessMapFile', label: 'Access Map File', type: 'file' },
        { key: 'admins', label: 'Parking Lot Admin/s', type: 'select', options: adminOptions, },
        { key: 'reservationTime', label: 'Reservation Time', type: 'select', options: [{ label: t('DayBefore'), value: 'day-before' }, { label: t('SameDay'), value: 'same-day' }], },
        { key: 'maxReservationDistance', label: 'Maximum Reservation Distance', type: 'text', required: false },
        { key: 'empty' },
        { key: 'avatar', label: 'Parking Lot Image File', type: 'file', },
        
        // { key: 'electricChargingTimeLimit', label: 'Electric Charging Time Limit', required: false, type: 'select', options: times, },
        // { key: 'allotmentMethod', label: 'Allotment Method', type: 'select', options: ['user-selected'], },
        // { key: 'daybefore', label: 'Day For Reservation Time', type: 'select', options: ['today', 'tomorrow'] },
        // { key: 'empty' },
        // { key: 'designated', label: 'Designated Parking Spots', type: 'text', required: false },
        // { key: 'regular', label: 'Regular Parking Spots', type: 'text', required: false },
        // { key: 'allotmentFile', label: 'Allotment File', type: 'file' },
        // { key: 'electric', label: 'Electric Charging Station', type: 'text', required: false },
    ];

    const handleChange = (e, key, type) => {
        if (key == 'avatar' || key == 'accessMapFile') {
            setUpdateAvatar(true)
            setUpdateAccessMapFile(true)
        }
        if (key == 'allotmentFile') {
            setupdateAllotmentFile(true)
        }
        const { value } = e.target;
        setparkinglotDetail((prevDetails) => {
            let updatedDetails = { ...prevDetails };
            if (key === 'electricChargingTimeLimit') {
                updatedDetails = {
                    ...updatedDetails,
                    chargingTimeLimit: value !== '',
                    chargingTimeStart: value !== '' ? value.split('-')[0] : '',
                    chargingTimeEnd: value !== '' ? value.split('-')[1] : '',
                    [key]: value,
                };
            } else if (key === 'smsSendTime') {
                updatedDetails = {
                    ...updatedDetails,
                    messageSendTime: value !== '' ? value.split(' ')[0] : '',
                    messageSendTimeOfDay: value.split(' ')[1] ? value.split(' ')[1] : '',
                    [key]: value
                }
            } else {
                updatedDetails[key] = type == 'file' ? e.target.files[0] : key == 'location' ? { ...parkinglotDetail?.location, name: e.target.value } : e.target.value
            }
            return updatedDetails;
        });

    };

    const isValidParkingLot = () => {
        const {
            name,
            accessMapFile,
            admins,
            allotmentMethod,
            location,
            avatar,
            smsSendTime,
            reservationTime,
            designatedReservationDuration
        } = parkinglotDetail;

        if (name == '' || accessMapFile == null || location.name == '' || admins.length == 0 || allotmentMethod == '' || avatar == null || smsSendTime == '' || reservationTime == '' || designatedReservationDuration == '') {
            return false
        }

        const durationPattern = /^(?:[01]\d|2[0-3]):(?:[0-5]\d)$/;
        if (!durationPattern.test(designatedReservationDuration)) {
            alert('Please Check Format of Designated Reservation Duration\nFor Example: hh:mm (i.e, 01:35)')
            return false;
        }

        return true;
    };

    const handleSubmit = (e) => {
        e.preventDefault();
        if (isValidParkingLot()) {
            if (updateAccessMapFile || updateAvatar) {
                dispatch(uploadImage({ data: parkinglotDetail, token: adminData?.token, id: data?._id, update: true }))
                console.log('image api call')
            } else if (updateAllotmentFile) {
                dispatch(uploadFile({ data: parkinglotDetail, token: adminData?.token, id: data?._id, update: true }))
                console.log('file api call')
            } else {
                dispatch(updateParkingLot({ data: parkinglotDetail, token: adminData?.token, id: data?._id }))
                console.log('update api call')
            }
            // setparkinglotDetail({
            //     name: '',
            //     designated: 0,
            //     accessMapFile: null,
            //     regular: 0,
            //     maxReservationDistance: '',
            //     admins: [],
            //     allotmentFile: null,
            //     electric: 0,
            //     allotmentMethod: '',
            //     electricChargingTimeLimit: '',
            //     parkingLotImageFile: null,
            //     location: {
            //         name: "",
            //         latitude: '',
            //         longitude: '',
            //     },
            //     avatar: null,
            //     chargingTimeLimit: false,
            //     chargingTimeStart: "",
            //     chargingTimeEnd: "",
            //     smsSendTime: '',
            //     reservationTime: ''
            // })
            // console.log('Form submitted:', parkinglotDetail);
        }
    };

    const [tableHeader, setTableHeader] = useState(
        [
            { title: t('areaname') },
            { title: t('regularparkingspot') },
            { title: t('electricchargingspot') },
            { title: t('designatedparkingspot') },
            { title: t('accessibleparkingspots') },
            { title: t('doubleparkingspots') },
            { title: t('frozenSpots') },
            { title: t('entrance') },
            { title: t('mapfile') },
            { title: '' },
        ]
    )

    useEffect(() => {
        setTableHeader(
            [
                { title: t('areaname') },
                { title: t('regularparkingspot') },
                { title: t('electricchargingspot') },
                { title: t('designatedparkingspot') },
                { title: t('accessibleparkingspots') },
                { title: t('doubleparkingspots') },
                { title: t('frozenSpots') },
                { title: t('entrance') },
                { title: t('mapfile') },
                { title: '' },
            ]
        )
    }, [i18n.language])


    useEffect(() => {
        setParkingSpots(parkingLevels?.levels)
    }, [parkingLevels])

    const parkingspot = {
        areaName: '',
        regularParkingSpots: '',
        electricChargingParkingSpots: '',
        designatedParkingspots: '',
        entrance: '',
    }

    const handleNewSpot = () => {
        if (parkingSpots.length == parkingLevels?.levels?.length) {
            setNewRow(true)
            setParkingSpots(prev => [...prev, parkingspot])
        }
    }

    useEffect(() => {
        if (data == null) {
            router.push('/parkingLots')
        } else {
            dispatch(getParkingLotLevels({
                parkingLotId: data?._id,
                token: adminData?.token
            }))
            if (allAdmins.length == 0) {
                dispatch(getAllAdmins({ token: adminData?.token }))
            }
        }

    }, [])

    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')
            }, 1000);
        }
    }, [adminData])

    const handleDeleteParkingLot = () => {
        dispatch(deleteParking({
            id: data?._id,
            token: adminData?.token
        }))
    }


    if (adminData?.token == undefined) {
        return <Loader />
    }

    return (
        <div>
            <Navbar active='parkinglot'>
                {loader && <Loader />}
                <div className='flex flex-row items-center justify-between mt-8 mx-12'>
                    <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  text-[30px]`}>{t('editParkingLot')}</h1>
                    <FontIcon handleClick={() => router.back()} size='xl' iconname={`fa-solid ${'fa-xmark'}`} className={`text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen } `} />
                </div>
                <div className='shadow-lg rounded-[15px] mt-3  mx-5 overflow-x-auto '>
                    <FontIcon handleClick={setDeleteLotModel} size='xl' iconname={`fa-solid fa-trash-can `} className={`text-appLightGrey ${adminData?.admin?.role == 'admin' ? 'flex' : 'invisible'} rounded-full mx-5 mt-5 hover:cursor-pointer hover:text-appSeaGreen 'hover:shadow-md`} />
                    <form onSubmit={handleSubmit} className='flex flex-col  items-center pt-2 mx-10 justify-center   '>
                        <div className='flex flex-wrap gap-3 w-full items-center '>
                            {formConfig.map((config) => (
                                <div className={`flex flex-col ${config.type == 'file' ? 'w-[13%]' : 'w-[20%]'} ${config.key == 'empty' && 'invisible'}  self-start`} key={config.key}>
                                    <label className={`${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}font-normal text-[15px] text-appBlack`} htmlFor={config.key}>{t(config.key)}</label>
                                    {config.type === 'select' ? (
                                        <Select
                                            required={false}
                                            id={config.key}
                                            name={config.key}
                                            value={parkinglotDetail[config.key]}
                                            onChange={(e) => handleChange(e, config.key)}
                                            className="mt-1  w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                            displayEmpty
                                            disabled={(adminData?.admin?.role == 'sub-admin' && config.key == 'admins')}
                                            multiple={config.key == 'admins' ? true : false}
                                        >
                                            <MenuItem value="" disabled>
                                                {config.key == 'electricChargingTimeLimit' ? t('nolimit') : t('adminSelectoption')}
                                            </MenuItem>
                                            {config?.options?.map((option) => {
                                                return <MenuItem key={config.key === 'admins' || config.key == 'reservationTime' || config.key == 'smsSendTime' ? option?.value : option} value={config.key === 'admins' || config.key == 'reservationTime' || config.key == 'smsSendTime' ? option?.value : option}>
                                                    {config.key === 'admins' || config.key == 'reservationTime' || config.key == 'smsSendTime' ? (i18n.language == 'he' && option?.labelHeb) ? option?.labelHeb : option?.label : (config.key === 'allotmentMethod' || config.key === 'smsSendTime' || config.key === 'reservationTime') ? t(option) : option}
                                                </MenuItem>
                                            })}
                                        </Select>
                                    ) : (
                                        <InputField
                                            disabled={config.key == 'designated' || config.key == 'regular' || config.key == 'electric' && true}
                                            required={false}
                                            type={config.type}
                                            id={config.key}
                                            name={config.key}
                                            value={config.key == 'location' ? parkinglotDetail[config.key].name : parkinglotDetail[config.key]}
                                            onChange={(e) => handleChange(e, config.key, config.type)}
                                            setparkinglotDetail={setparkinglotDetail}
                                            parkinglotDetail={parkinglotDetail}
                                        />
                                    )
                                    }
                                    {config.key == 'designatedReservationDuration' && <p className={`text-appGreyLight42 ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik '} font-normal text-[11px] pt-1 `}>{t('timeformat')}</p>}
                                    {config.key != 'electricChargingTimeLimit' && config.key != 'allotmentFile' && <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} ${config.key == 'empty' && 'invisible'} font-normal text-[11px] pt-1 ${((parkinglotDetail[config.key] == '' || parkinglotDetail[config.key] == null) && config.required != false) ? 'visible' : 'invisible'}`}>{config.type == 'file' ? t('uploadfillalert') : t('fillalert')}</p>}
                                    {(config.key == 'allotmentFile' && parkinglotDetail.allotmentMethod == 'manual' && parkinglotDetail.allotmentFile == null) && <p className={`text-appRed  ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} ${config.key == 'empty' && 'invisible'} font-normal text-[11px] pt-1`}>{t('uploadfillalert')}</p>}

                                </div>
                            ))}
                        </div>
                        <div className='flex pb-6 mt-4 items-center justify-center'>
                            <button
                                type='submit'
                                className={`bg-transparent transition-all delay-100 hover:bg-appSeaGreen hover:text-appWhite w-[108px] h-[40px] text-appSeaGreen border-2 border-appSeaGreen  rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-bold font-spartan' : 'font-rubik font-medium'} cursor-pointer `}
                            >
                                {t('save')}
                            </button>
                        </div>
                    </form>



                </div>

                <div className='rounded-[15px] max-h-[42%] overflow-y-auto  pb-4 shadow-lg my-5 mx-5'>
                    <div className='flex items-center justify-between mx-10 pt-[41px] '>
                        <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} text-appBlack  text-[22px]`}>{t('parkingspotares')}</h1>
                        <div className='flex items-center justify-center gap-[15px]'>
                            <FontIcon handleClick={() => handleNewSpot()} size='xl' iconname="fa-solid fa-circle-plus" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md ' />
                        </div>
                    </div>
                    <div className=' mt-10 max-w-full  mx-10'>
                        <SpotParking tableHeader={tableHeader} Details={parkingSpots || []} isNewRow={newRow} setNewRow={(check) => setNewRow(check)} parkingLot={data} />
                    </div>
                </div>


                <Modal isOpen={deleteLotModel} onClose={setDeleteLotModel} >
                    <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
                        <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                    </div>
                    <Image onClick={() => setDeleteLotModel(false)} className={`mt-5 mx-3 ${i18n.language == 'he' && 'transform rotate-180'} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

                    <div className='w-[430px]'>
                        <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}  font-normal text-center text-[18px] mt-4 px-10`}>
                            {t('deleteparkinglotmodeltxt1')}<br />
                            {t('deleteparkinglotmodeltxt2')}
                        </p>
                    </div>
                    <div className='flex   mt-8 items-center justify-center'>
                        <button
                            onClick={() => handleDeleteParkingLot()}
                            className={`bg-transparent mb-7 w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-bold font-spartan' : 'font-rubik font-medium'}  cursor-pointer `}
                        >
                            {t('accept')}
                        </button>
                    </div>
                </Modal>

            </Navbar>
        </div>
    )
}

export default editParkingLots