import FaultDiscriptionList from '@/components/FaultDiscriptionList'
import Modal from '@/components/model'
import Navbar from '@/components/navbar'
import { addArchieve, deleteFaultReport, exportReportsList, getFaultReport } from '@/store/userReducer'
import { IMAGES, svgImages } from '@/utilities/utils'
import Image from 'next/image'
import React, { useEffect, useState } from 'react'
import { useSelector, useDispatch } from 'react-redux';
import Loader from './Loader'
import { useRouter } from 'next/router'
import { useTranslation } from 'react-i18next'
import i18n from '../../i18n'
import ToggleLanguageButton from '@/components/ToggleLanguageButton'
import dynamic from 'next/dynamic'

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


function FaultReports() {
  const { t } = useTranslation()
  const { faultReports, adminData, loader } = useSelector(state => state.user)
  const dispatch = useDispatch()
  const router = useRouter()
  const [isVisible, setIsVisible] = useState(false)
  const [deleteReportid, setDeleteReportId] = useState('')
  const [tableHeader, setTableHeader] = useState(
    [
      { title: t('parkinglotname') },
      { title: t('username') },
      { title: t('phoneNumber') },
      { title: t('email') },
      { title: t('faultdiscrption') },
      { title: t('reportdatetime') },
      { title: t('action') },
    ]
  )


  const handleSetId = (id) => {
    setDeleteReportId(id)
    setIsVisible(true)
  }

  const handleReport = () => {
    dispatch(addArchieve({ id: deleteReportid, token: adminData?.token }))
    setIsVisible(false)
  }

  useEffect(() => {
    setTableHeader([
      { title: t('parkinglotname') },
      { title: t('username') },
      { title: t('phoneNumber') },
      { title: t('email') },
      { title: t('faultdiscrption') },
      { title: t('reportdatetime') },
      { title: t('action') },
    ])
  }, [i18n.language])

  useEffect(() => {
    if (adminData?.token) {
      dispatch(getFaultReport({ token: adminData?.token }))
    } else if (adminData?.token == undefined) {
      setTimeout(() => {
        router.push('/')
      }, 1000);
    }
  }, [adminData])

  if (adminData?.token == undefined) {
    return <Loader />
  }

  return (
    <div>
      <Navbar active='report'>
        {loader && <Loader />}
        <div className='flex mt-[27px] mx-[49px] items-center justify-between'>
          <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  text-[30px]   inline-block`}>{t('report')}</h1>
          <div className='relative flex items-center justify-center group'>
            <FontIcon handleClick={() => { dispatch(exportReportsList()) }} size='2xl' iconname="fa-solid fa-file-arrow-down" className='text-appLightGrey rounded-full invert hover:invert-0 hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md' />
            <p className={`${i18n.language == 'en' ? 'font-spartan -left-4' : 'font-rubik -left-2.5'} text-appWhite  text-[10px] absolute z-10 bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -bottom-14 invisible text-center group-hover:visible transition-opacity duration-300`}>{t('exportreport')}</p>
          </div>
        </div>
        <div className='max-w-full rounded-2xl mt-5 mx-5 shadow-xl pb-8' >
          <div className=' mt-10 max-w-full  mx-10'>
            <FaultDiscriptionList handleModal={handleSetId} tableHeader={tableHeader} Details={faultReports?.complaints ? faultReports?.complaints : []} />
          </div>
        </div>
      </Navbar>
      <Modal isOpen={isVisible} onClose={setIsVisible} >

        <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
          <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
        </div>


        <Image onClick={() => { setIsVisible(false) }} className={`mt-5 mx-3 ${i18n.language == 'he' && 'transform rotate-180'} hover:cursor-pointer`} alt='backbtn' src={svgImages.modalbackbtn} />

        <div className='w-[430px]'>
          <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}  font-normal text-center text-[18px] mt-4`}>
            {t('deletereportmodel')}</p>
        </div>

        <div className='flex  pb-5 mt-8 items-center justify-center'>
          <button
            onClick={() => handleReport()}
            className={`bg-transparent w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} cursor-pointer `}
          >
            {t('accept')}
          </button>
        </div>
      </Modal>
    </div>
  )
}

export default FaultReports