import Image from 'next/image'
import { IMAGES } from '../utilities/utils'
import { useEffect, useState } from 'react'
import Link from 'next/link'
import { useRouter } from 'next/router';
import { useSelector, useDispatch } from 'react-redux';
import { loginAdmin } from '@/store/userReducer';
import Loader from './Loader';
import { useTranslation } from 'react-i18next';
import ToggleLanguageButton from '@/components/ToggleLanguageButton';
import i18n from '../../i18n';




export default function Home() {
  const { t } = useTranslation();
  const { loader, adminData, error } = useSelector(state => state.user)
  const dispatch = useDispatch()
  const router = useRouter()

  const [formData, setFormData] = useState({
    email: '',
    password: '',
  });
  const formFields = [
    { label: 'Email', type: 'email', name: 'email' },
    { label: 'Password', type: 'password', name: 'password' },
  ];

  const [err, setErr] = useState({
    usernameErr: '',
    passErr: ''
  })

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({
      ...formData,
      [name]: value,
    });
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    dispatch(loginAdmin(formData))
  };

  // console.log('errrorrr =====',error)

  useEffect(() => {
    if (error?.message == 'Admin not found.') {
      console.log('at not found')
      setErr({ passErr: t('incorrectPassword'), usernameErr: t('emailincorrect') })
    } else if (error?.message?.split('.')[0] == 'Incorrect Password') {
      console.log('at incorrect')
      setErr({ passErr: t('incorrectPassword'), usernameErr: '' })
    } else if (error?.message == 'Too many failed login attempts. Your account has been locked, please contact the administration.') {
      setErr({ passErr: error?.message, usernameErr: '' })
    } else if (adminData && Object.keys(adminData).length !== 0) {
      setErr({ passErr: '', usernameErr: '' })
    }
  }, [adminData, error])


  return (
    <>
      {loader && <Loader />}
      <div className={`bg-[url('../assets/images/authBg.png')]  h-[41rem]  bg-cover w-full`}>

        <div className='flex justify-center item-center'>
          <Image alt='logo' src={IMAGES.logo} width={200} height={150} className='mt-[40px] object-contain ' />
        </div>
        <h1 className={`text-center mt-[200px] text-3xl ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} `} >{t('welcome')} </h1>

        <form onSubmit={handleSubmit} className=''>
          {formFields.map((field, index) => (
            <div key={field.name} className='flex items-center justify-center' >
              <div className='flex-col mt-[34px] w-[388px] '>
                <p className={`${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[15px] text-appBlack`}>{t(field.type)}</p>
                <input
                  required
                  type={field.type}
                  name={field.name}
                  value={formData[field.name]}
                  onChange={handleChange}
                  className='w-full mt-2 rounded-md bg-appOffWhite shadow-md h-[42px] px-2 custom-input'
                />
                <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal text-[11px] mt-2`} >{field.name == 'email' && err.usernameErr != '' ? err.usernameErr : field.name == 'password' && err.passErr != '' && err.passErr}</p>
              </div>
            </div>
          ))}
          <div className='flex mt-[50px] items-center justify-center'>
            <button
              type='submit'
              className={`bg-appSeaGreen w-[134px] h-[59px] text-appWhite rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-bold font-spartan' : 'font-rubik font-medium'}  cursor-pointer`}
            >
              {t('login')}
            </button>
          </div>
        </form>

        <div className='flex justify-center items-center mt-1'>
          <Link className={`mt-1 underline ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-light text-[15px] text-appBlack `} href='/forgetPassword'>{t('forgetpassword')}</Link>
        </div>

        <div className='flex items-center justify-center mx-3'>
          <ToggleLanguageButton />
          <Image alt='ybsLogo' className='pb-5 mx-auto mt-[18px] ' objectFit='contain' width={58} height={45} src={IMAGES.YBS_Logo} />
          <div className='invisible' >
            <ToggleLanguageButton />
          </div>
        </div>
      </div>


      <style jsx>{`
        .custom-input:focus {
          border-color: #4EB9B1;
          outline: none;
          box-shadow: 0 0 0 2px rgba(78, 185, 177, 0.5);
        }
      `}</style>
    </>
  )
}
