import Navbar from '@/components/navbar'
import React, { useEffect, useState } from 'react'
import { useTranslation } from 'react-i18next'
import i18n from '../../i18n'
import SlotStatusInfo from '@/components/SlotStatusInfo';
import CustomDropDown from '@/components/CustomDropDown';
import LevelSlots from '@/components/LevelSlots';
import Image from 'next/image';
import { IMAGES, svgImages } from '@/utilities/utils';
import { useRouter } from 'next/router';
import { useDispatch, useSelector } from 'react-redux';
import Loader from './Loader';
import { exportmonitoringList, getAllMonitoringLots, getParkingLots } from '@/store/userReducer';
import { setMonitoringState } from '@/store/userSlice';
import dynamic from 'next/dynamic';

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })


const monitoring = () => {
    const { t } = useTranslation()
    const dispatch = useDispatch()
    const { adminData, loader, parkingLots, monitoringLevelsSpots, monitoringState } = useSelector(state => state.user)
    const [parkingsLots, setParkingsLots] = useState(parkingLots?.parkingLots || null)
    const [levels_Spots, setLevels_Spots] = useState(monitoringLevelsSpots)
    const [toggledropdown, setToggleDropdown] = useState(false)
    const [fullScreen, setFullScreen] = useState(false)
    const router = useRouter()
    const monitoringdata = router.query.data ? JSON.parse(router.query.data) : null
    const [selectedLot, setSelectedLot] = useState(null)


    useEffect(() => {
        setLevels_Spots(monitoringLevelsSpots)
    }, [monitoringLevelsSpots])

    useEffect(() => {
        setParkingsLots(parkingLots?.parkingLots)
    }, [parkingLots])

    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')
            }, 1000);
        } else if (adminData?.token && parkingLots?.length == 0) {
            dispatch(getParkingLots({ token: adminData?.token, currentAdmin: adminData?.admin?._id }))
        }
    }, [adminData, parkingLots])

    useEffect(() => {
        if (selectedLot) {
            dispatch(getAllMonitoringLots({ id: selectedLot?._id }))
        }
    }, [selectedLot])

    useEffect(() => {
        if (!selectedLot) {
            setSelectedLot(monitoringdata ? monitoringdata : monitoringState?.selectedlot ? monitoringState?.selectedlot : parkingsLots?.[0])
            if (!monitoringState?.selectedlot) {
                dispatch(setMonitoringState(parkingsLots?.[0]))
            } else if (monitoringdata) {
                dispatch(setMonitoringState(monitoringdata))
            }
        }
    }, [parkingsLots])


    return (
        <Navbar fullScreen={fullScreen} active='monitoring'>
            {loader && <Loader />}
            <div className='bg-appBlack2C px-3 h-14 border-b border-appdarkgreen flex items-center justify-between '>
                <div className='flex items-center gap-2'>
                    {fullScreen && <Image onClick={() => router.push('/dashboard')} className='cursor-pointer' height={47} width={48.74} src={svgImages.SpotPark_Logo} />}
                    <p className={`${i18n.language == 'en' ? 'font-spartan' : 'font-rubik '} text-appNewSeaGreen font-medium text-[30px] bg-appBlack2C`}>{t('controlCenter')}</p>
                    <CustomDropDown selectedLot={selectedLot} setSelectedLot={(lot) => { setSelectedLot(lot); dispatch(setMonitoringState(lot)) }} lotdetails={parkingsLots} toggledropdown={toggledropdown} setToggleDropdown={() => setToggleDropdown(!toggledropdown)} />
                    <div className='relative flex items-center justify-center group mt-1 mx-1'>
                        <FontIcon handleClick={() => { dispatch(exportmonitoringList({ id: selectedLot?._id })) }} size='2xl' iconname="fa-solid fa-file-arrow-down" className='text-appLightGrey rounded-full  hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md' />
                        <p className={`${i18n.language == 'en' ? 'font-spartan -left-6' : 'font-rubik -left-2.5'} text-appWhite z-[10] text-[10px] absolute bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -bottom-14 invisible text-center group-hover:visible transition-opacity duration-300`}>{t('exportmonitoring')}</p>
                    </div>
                </div>
                <Image onClick={() => setFullScreen(!fullScreen)} alt='fullscreenicon' width={32} height={32} src={svgImages.Fullscreen} />
                {/* <SlotStatusInfo setFullScreen={() => setFullScreen(!fullScreen)} /> */}
            </div>

            {!loader && <div className='flex w-full h-[94%]'>
                <div className={`h-full w-[228px] ${i18n.language == 'en' ? 'pl-4' : 'pr-4'}`}>
                    <h1 className={`${i18n.language == 'en' ? 'font-spartan text-[22px]' : 'font-rubik text-[32px]'} mt-2 text-appWhite`}>{monitoringLevelsSpots?.levels?.length == 1 ? monitoringLevelsSpots?.levels?.[0]?.level?.name : t('newMonitoringAllParkingLot')}</h1>
                    <div className={`flex flex-col gap-10 mt-5 h-[80%] ${i18n.language == 'en' ? 'border-r' : 'border-l'} border-appgrey95`}>
                        <div className='flex flex-col gap-2'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[18px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.totalCounts?.regular} {t('newMonitoringRegular')} </p>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.empty} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.regular?.free} {t('newMonitoringFree')} </p>
                            </div>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.emptyred} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.regular?.reserved} {t('newMonitoringReserved')}  </p>
                            </div>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.inuse} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.regular?.taken} {t('newMonitoringTaken')} </p>
                            </div>
                        </div>
                        <div className='flex flex-col gap-2'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[18px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.totalCounts?.disabled} {t('newMonitoringAccessible')} </p>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.emptyblue} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.disabled?.free} {t('newMonitoringFree')} </p>
                            </div>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.accessible} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.disabled?.taken} {t('newMonitoringTaken')} </p>
                            </div>

                        </div>
                        <div className='flex flex-col gap-2'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[18px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.totalCounts?.electric} {t('newMonitoringElectric')} </p>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.electricwhite} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.electric?.free} {t('newMonitoringFree')} </p>
                            </div>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.electricred} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.electric?.taken} {t('newMonitoringTaken')} </p>
                            </div>

                        </div>
                        <div className='flex flex-col gap-2'>
                            <p className={`${i18n.language == 'en' ? 'font-spartan text-[18px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.designated?.frozen} {t('newMonitoringFrozen')} </p>
                            <div className='flex items-center justify-start gap-2'>
                                <Image height={22} width={22} alt='icons' src={IMAGES.locked} />
                                <p className={`${i18n.language == 'en' ? 'font-spartan text-[16px]' : 'font-rubik text-[24px]'} text-appWhite`}>{monitoringLevelsSpots?.counts?.designated?.frozen} {t('newMonitoringFrozen')} </p>
                            </div>

                        </div>
                    </div>
                </div>
                <LevelSlots selectedLot={levels_Spots} />
            </div>}


            {/* <div className='bg-appBlack2C w-full h-[9.4%] '>
                <p className={`${i18n.language == 'en' ? 'font-spartan' : ' font-rubik'} font-medium text-[24px] text-appgrey95 px-20 `}>{t('availablespaces')}</p>
                <div className='flex items-center gap-3 justify-center '>
                    {levels_Spots?.levels?.length == 1 && <p className={`font-rubik font-medium text-[24px] text-appgrey95`}>{levels_Spots?.levels?.[0]?.level?.name}-</p>}
                    <p className={`font-rubik font-medium text-[24px] text-white`}>{t('monitoringRegularCount')} {levels_Spots?.totalRegularCount}</p>
                    <div className='w-[2px] h-[20px] bg-appgrey99' />
                    <p className={`font-rubik font-medium text-[24px] text-white`}>{t('monitoringAccessibleCount')} {levels_Spots?.totalDisabledCount}</p>
                    <div className='w-[2px] h-[20px] bg-appgrey99' />
                    <p className={`font-rubik font-medium text-[24px] text-white`}>{t('monitoringElectricCount')} {levels_Spots?.totalElectricCount}</p>
                </div>
            </div> */}


        </Navbar >
    )
}

export default monitoring