import Navbar from '@/components/navbar'
import React, { useEffect, useState } from 'react'
import Loader from './Loader'
import dynamic from 'next/dynamic'
import { useDispatch, useSelector } from 'react-redux'
import i18n from '../../i18n'
import { useTranslation } from 'react-i18next'
import { useRouter } from 'next/router'
import OccupancyList from '@/components/OccupancyList'
import { exportmonitoringList, getAllMonitoringLots } from '@/store/userReducer'
import { setParkingLotNameOccupancy } from '@/store/userSlice'

const FontIcon = dynamic(() => import('../components/FontIcon'), { ssr: false })

const parkingLotOccupancy = () => {
    const router = useRouter()
    const { t } = useTranslation()
    const { adminData, loader, monitoringLevelsSpots, parkinglotnameoccupancy } = useSelector(state => state.user)
    const dispatch = useDispatch()

    const data = router.query.data ? JSON.parse(router.query.data) : null

    const [occupancyDetails, setOccupancyDetails] = useState([])
    const [tableHeader, setTableHeader] = useState(
        [
            { title: t('occupancyparkinglot') },
            { title: t('occupancyareaname') },
            { title: t('occupancyparkingspotnumber') },
            { title: t('occupancyparkingspottype') },
            { title: t('occupancyparkingspotstatus') },
            { title: t('occupancyspotdesignatedto') },
            { title: t('occupancyspotoccupancy') },
            { title: t('occupancyphonenumber') },


        ]
    )

    useEffect(() => {
        setTableHeader([
            { title: t('occupancyparkinglot') },
            { title: t('occupancyareaname') },
            { title: t('occupancyparkingspotnumber') },
            { title: t('occupancyparkingspottype') },
            { title: t('occupancyparkingspotstatus') },
            { title: t('occupancyspotdesignatedto') },
            { title: t('occupancyspotoccupancy') },
            { title: t('occupancyphonenumber') },

        ])
    }, [i18n.language])

    useEffect(() => {
        setOccupancyDetails(monitoringLevelsSpots?.levels)
    }, [monitoringLevelsSpots])

    useEffect(() => {
        if (adminData?.token == undefined) {
            setTimeout(() => {
                router.push('/')
            }, 1000);
        } else if (adminData?.token) {
            if (data) {
                dispatch(getAllMonitoringLots({ id: data?._id }))
                dispatch(setParkingLotNameOccupancy(data))
            }
        }
    }, [adminData])

    if (adminData?.token == undefined) {
        return <Loader />
    }

    return (
        <>
            <Navbar active={'parkinglot'}>
                {loader && <Loader />}
                <div className='flex flex-row items-center justify-between mt-8 mx-12'>
                    <div className='flex items-center justify-center gap-2'>
                        <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  text-[30px]`}>{t('occupancytitle')}</h1>
                        <div className='relative flex items-center justify-center group mx-1'>
                            <FontIcon handleClick={() => { dispatch(exportmonitoringList({ id: data?._id ? data?._id : parkinglotnameoccupancy?._id })) }} size='2xl' iconname="fa-solid fa-file-arrow-down" className='text-appLightGrey rounded-full  hover:cursor-pointer hover:text-appSeaGreen hover:shadow-md' />
                            <p className={`${i18n.language == 'en' ? 'font-spartan -left-6' : 'font-rubik -left-2.5'} text-appWhite z-[10] text-[10px] absolute bg-appgreyBE px-2 py-0.5 rounded-md shadow-lg -bottom-14 invisible text-center group-hover:visible transition-opacity duration-300`}>{t('exportmonitoring')}</p>
                        </div>
                    </div>
                    <FontIcon handleClick={() => router.back()} size='xl' iconname={`fa-solid ${'fa-xmark'}`} className={`text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen } `} />
                </div>
                <div className='max-w-full  rounded-2xl my-5 mx-5 shadow-xl pb-8' >
                    <div className=' mt-10 mx-10'>
                        <OccupancyList parkinglotname={data ? data?.name : parkinglotnameoccupancy?.name} tableHeader={tableHeader} Details={occupancyDetails || []} />
                    </div>
                </div>

            </Navbar>
        </>
    )
}

export default parkingLotOccupancy